@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -19,6 +19,8 @@
 
 
 import codecs
+import Cookie
+from cStringIO import StringIO
 import mimetypes
 import os
 import requests
@@ -29,19 +31,20 @@ from tempfile import mkdtemp
 from urllib2 import URLError, HTTPError
 from urlparse import urlparse
 
+from django.contrib.auth.models import User
+from django.contrib.staticfiles import finders
 from django.test import LiveServerTestCase
 from django.test import TransactionTestCase
 from django.test.client import Client
 from django.utils import translation
 from django.utils.importlib import import_module
 
-from wirecloud.platform.localcatalogue.utils import install_resource_to_all_users
+from wirecloud.platform.localcatalogue.utils import install_resource
 from wirecloud.platform.widget import utils as showcase
-from wirecloud.proxy.tests import FakeDownloader as ProxyFakeDownloader
 from wirecloud.proxy.views import WIRECLOUD_PROXY
 from wirecloud.catalogue import utils as catalogue
 from wirecloud.commons.utils import downloader
-from wirecloud.commons.utils.remote import WirecloudRemoteTestCase
+from wirecloud.commons.utils.remote import MobileWirecloudRemoteTestCase, WirecloudRemoteTestCase
 from wirecloud.commons.utils.wgt import WgtDeployer, WgtFile
 
 
@@ -100,6 +103,10 @@ class DynamicWebServer(object):
 
     responses = {}
 
+    def __init__(self, fallback=None):
+
+        self.fallback = fallback
+
     def add_response(self, method, path, response_body):
 
         if path not in self.responses:
@@ -114,9 +121,18 @@ class DynamicWebServer(object):
 
         parsed_url = urlparse(url)
         if parsed_url.path not in self.responses or method not in self.responses[parsed_url.path]:
-            raise HTTPError('url', '404', 'Not Found', None, None)
 
-        return self.responses[parsed_url.path][method]
+            if self.fallback is not None:
+                return self.fallback.request(method, url, *args, **kwargs)
+            else:
+                return {'status_code': 404, 'reason': 'Not Found'}
+
+        response = self.responses[parsed_url.path][method]
+
+        if callable(response):
+            response = response(method, url, *args, **kwargs)
+
+        return response
 
 
 class LiveServer(object):
@@ -126,7 +142,25 @@ class LiveServer(object):
 
     def request(self, method, url, *args, **kwargs):
 
-        return getattr(self._client, method.lower())(url)
+        parsed_url = urlparse(url)
+        if parsed_url.path.startswith('/static/'):
+            if method != 'GET':
+                raise HTTPError('url', '405', 'Method not allowed', None, None)
+
+            final_path = finders.find(parsed_url.path[8:])
+            f = codecs.open(final_path, 'rb')
+            contents = f.read()
+            f.close()
+
+            return {
+                'headers': {
+                    'Content-Type': mimetypes.guess_type(final_path, strict=False)[0],
+                    'Content-Length': len(contents),
+                },
+                'content': contents,
+            }
+        else:
+            return getattr(self._client, method.lower())(url)
 
 
 class LocalFileSystemServer(object):
@@ -155,12 +189,13 @@ class LocalFileSystemServer(object):
                 'content': contents,
             }
         else:
-            raise HTTPError('url', '404', 'Not Found', None, None)
+            return {'status_code': 404, 'reason': 'Not Found'}
 
 
 class FakeNetwork(object):
 
     old_download_function = None
+    old_requests_request = None
     old_requests_get = None
     old_requests_post = None
 
@@ -170,77 +205,72 @@ class FakeNetwork(object):
     def __call__(self, method, url, *args, **kwargs):
         parsed_url = urlparse(url)
 
+        if 'data' not in kwargs or kwargs['data'] is None:
+            kwargs['data'] = StringIO('')
+
         if parsed_url.scheme not in self._servers or parsed_url.netloc not in self._servers[parsed_url.scheme]:
             raise URLError('not valid')
 
         server = self._servers[parsed_url.scheme][parsed_url.netloc]
         return server.request(method, url, *args, **kwargs)
 
+    def _prepare_response(self, res_info, url):
+
+        res = requests.Response()
+        res.url = res_info.get('url', url)
+        res.status_code = res_info.get('status_code', 200)
+        if 'reason' in res_info:
+            res.reason = res_info['reason']
+
+        if 'headers' in res_info:
+            res.headers.update(res_info['headers'])
+
+            if 'Set-Cookie' in res_info['headers']:
+                cookies = Cookie.SimpleCookie()
+                for entry in res_info['headers']['Set-Cookie'].split(','):
+                    cookies.load(entry)
+                res.cookies.update(cookies)
+
+        content = res_info.get('content', '')
+        if not hasattr(content, 'read') or not callable(content.read):
+            res.raw = StringIO(content)
+        else:
+            res.raw = content
+
+        return res
+
     def mock_requests(self):
 
-        if self.old_requests_get is not None:
+        if self.old_requests_request is not None:
             return
 
+        def request_mock(method, url, *args, **kwargs):
+            res_info = self(method.upper(), url, *args, **kwargs)
+            return self._prepare_response(res_info, url)
+
         def get_mock(url, *args, **kwargs):
             res_info = self('GET', url, *args, **kwargs)
-
-            res = requests.Response()
-            res.url = res_info.get('url', url)
-            res.status_code = res_info.get('status_code', 200)
-            if 'headers' in res_info:
-                res.headers.update(res_info['headers'])
-            res._content = res_info.get('content', '')
-            return res
+            return self._prepare_response(res_info, url)
 
         def post_mock(url, *args, **kwargs):
             res_info = self('POST', url, *args, **kwargs)
+            return self._prepare_response(res_info, url)
 
-            res = requests.Response()
-            res.url = res_info.get('url', url)
-            res.status_code = res_info.get('status_code', 200)
-            if 'headers' in res_info:
-                res.headers.update(res_info['headers'])
-            res._content = res_info.get('content', '')
-            return res
-
+        self.old_requests_request = requests.request
+        requests.request = request_mock
         self.old_requests_get = requests.get
         requests.get = get_mock
         self.old_requests_post = requests.post
         requests.post = post_mock
 
     def unmock_requests(self):
+        requests.request = self.old_requests_request
         requests.get = self.old_requests_get
         requests.post = self.old_requests_post
+        self.old_requests_request = None
         self.old_requests_get = None
         self.old_requests_post = None
 
-    def mock_downloader(self):
-
-        if self.old_download_function is not None:
-            return
-
-        self.old_download_function = staticmethod(downloader.download_http_content)
-
-        def downloader_mock(url, *args, **kwargs):
-
-            parsed_url = urlparse(url)
-            if parsed_url.scheme == 'file':
-                f = codecs.open(parsed_url.path, 'rb')
-                contents = f.read()
-                f.close()
-                return contents
-
-            res_info = self('GET', url)
-
-            return res_info.get('content', '')
-
-        downloader.download_http_content = downloader_mock
-
-    def unmock_downloader(self):
-
-        downloader.download_http_content = self.old_download_function
-        self.old_download_function = None
-
 
 class WirecloudTestCase(TransactionTestCase):
 
@@ -264,10 +294,10 @@ class WirecloudTestCase(TransactionTestCase):
             'http': {
                 'localhost:8001': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data', 'src')),
                 'macs.example.com': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data')),
+                'example.com': DynamicWebServer(),
             },
         }))
         cls.network.mock_requests()
-        cls.network.mock_downloader()
 
         # catalogue deployer
         cls.old_catalogue_deployer = catalogue.wgt_deployer
@@ -310,7 +340,6 @@ class WirecloudTestCase(TransactionTestCase):
 
         # Unmock network requests
         cls.network.unmock_requests()
-        cls.network.unmock_downloader()
 
         super(WirecloudTestCase, cls).tearDownClass()
 
@@ -320,6 +349,12 @@ class WirecloudTestCase(TransactionTestCase):
         restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
         restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
 
+        # clean example.com responses
+        try:
+            self.network._servers['http']['example.com'].clear()
+        except:
+            pass
+
         # cache
         from django.core.cache import cache
         cache.clear()
@@ -336,7 +371,7 @@ class WirecloudTestCase(TransactionTestCase):
         translation.activate(new_language)
 
 
-def uses_extra_resources(resources, shared=False):
+def uses_extra_resources(resources, shared=False, public=True, users=(), groups=()):
 
     def wrap(test_func):
 
@@ -350,7 +385,19 @@ def uses_extra_resources(resources, shared=False):
             for resource in resources:
                 wgt_file = open(os.path.join(base, resource), 'rb')
                 wgt = WgtFile(wgt_file)
-                resource = install_resource_to_all_users(file_contents=wgt, packaged=True)
+
+                resource = install_resource(wgt, None, None, True)
+
+                if public:
+                    resource.public = True
+                    resource.save()
+
+                final_users = (User.objects.get(username=user) for user in users)
+                resource.users.add(*final_users)
+
+                final_groups = (Group.objects.get(name=group) for group in groups)
+                resource.groups.add(*final_groups)
+
                 wgt_file.close()
 
             return test_func(self, *args, **kwargs)
@@ -385,13 +432,10 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
             'http': {
                 'localhost:8001': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data', 'src')),
                 'macs.example.com': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data')),
+                'example.com': DynamicWebServer(),
             },
         }))
         cls.network.mock_requests()
-        cls.network.mock_downloader()
-        cls._original_proxy_do_request_function = WIRECLOUD_PROXY._do_request
-        WIRECLOUD_PROXY._do_request = ProxyFakeDownloader()
-        WIRECLOUD_PROXY._do_request.set_response('http://example.com/success.html', 'remote makerequest succeded')
 
         # catalogue deployer
         cls.old_catalogue_deployer = catalogue.wgt_deployer
@@ -434,8 +478,6 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
 
         # Unmock network requests
         cls.network.unmock_requests()
-        cls.network.unmock_downloader()
-        WIRECLOUD_PROXY._do_request = cls._original_proxy_do_request_function
 
         # deployers
         catalogue.wgt_deployer = cls.old_catalogue_deployer
@@ -458,8 +500,114 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
         restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
         restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
         cache.clear()
+        try:
+            self.network._servers['http']['example.com'].clear()
+        except:
+            pass
+
         super(WirecloudSeleniumTestCase, self).setUp()
 
+
+class MobileWirecloudSeleniumTestCase(LiveServerTestCase, MobileWirecloudRemoteTestCase):
+
+    fixtures = ('initial_data', 'selenium_test_data')
+    __test__ = False
+
+    @classmethod
+    def setUpClass(cls):
+
+        from django.conf import settings
+
+        MobileWirecloudRemoteTestCase.setUpClass.im_func(cls)
+
+        cls.old_LANGUAGES = settings.LANGUAGES
+        cls.old_LANGUAGE_CODE = settings.LANGUAGE_CODE
+        cls.old_DEFAULT_LANGUAGE = settings.DEFAULT_LANGUAGE
+        settings.LANGUAGES = (('en', 'English'),)
+        settings.LANGUAGE_CODE = 'en'
+        settings.DEFAULT_LANGUAGE = 'en'
+
+        # Mock network requests
+        cls.network = FakeNetwork(getattr(cls, 'servers', {
+            'http': {
+                'localhost:8001': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data', 'src')),
+                'macs.example.com': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data')),
+                'example.com': DynamicWebServer(),
+            },
+        }))
+        cls.network.mock_requests()
+
+        # catalogue deployer
+        cls.old_catalogue_deployer = catalogue.wgt_deployer
+        cls.catalogue_tmp_dir_backup = mkdtemp()
+        cls.catalogue_tmp_dir = mkdtemp()
+        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
+
+        # showcase deployer
+        cls.old_deployer = showcase.wgt_deployer
+        cls.localcatalogue_tmp_dir_backup = mkdtemp()
+        cls.tmp_dir = mkdtemp()
+        showcase.wgt_deployer = WgtDeployer(cls.tmp_dir)
+
+        # deploy resource files
+        operator_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_TestOperator_1.0.zip'), 'rb')
+        operator_wgt = WgtFile(operator_wgt_file)
+        catalogue.add_widget_from_wgt(operator_wgt_file, None, wgt_file=operator_wgt, deploy_only=True)
+        showcase.wgt_deployer.deploy(operator_wgt)
+        operator_wgt_file.close()
+
+        widget_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_Test_1.0.wgt'))
+        widget_wgt = WgtFile(widget_wgt_file)
+        catalogue.add_widget_from_wgt(widget_wgt_file, None, wgt_file=widget_wgt, deploy_only=True)
+        showcase.wgt_deployer.deploy(widget_wgt)
+        widget_wgt_file.close()
+
+        restoretree(cls.tmp_dir, cls.localcatalogue_tmp_dir_backup)
+        restoretree(cls.catalogue_tmp_dir, cls.catalogue_tmp_dir_backup)
+
+        LiveServerTestCase.setUpClass.im_func(cls)
+
+        cls.network._servers['http'][cls.server_thread.host + ':' + str(cls.server_thread.port)] = LiveServer()
+
+    @classmethod
+    def tearDownClass(cls):
+
+        from django.conf import settings
+
+        MobileWirecloudRemoteTestCase.tearDownClass.im_func(cls)
+
+        # Unmock network requests
+        cls.network.unmock_requests()
+
+        # deployers
+        catalogue.wgt_deployer = cls.old_catalogue_deployer
+        shutil.rmtree(cls.catalogue_tmp_dir_backup, ignore_errors=True)
+        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
+        showcase.wgt_deployer = cls.old_deployer
+        shutil.rmtree(cls.localcatalogue_tmp_dir_backup, ignore_errors=True)
+        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
+
+        settings.LANGUAGES = cls.old_LANGUAGES
+        settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
+        settings.DEFAULT_LANGUAGE = cls.old_DEFAULT_LANGUAGE
+
+        super(MobileWirecloudSeleniumTestCase, cls).tearDownClass()
+
+    def setUp(self):
+
+        from django.core.cache import cache
+
+        restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
+        restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
+        cache.clear()
+        try:
+            self.network._servers['http']['example.com'].clear()
+        except:
+            pass
+
+        super(MobileWirecloudSeleniumTestCase, self).setUp()
+
+
 DEFAULT_BROWSER_CONF = {
     'Firefox': {
         'CLASS': 'selenium.webdriver.Firefox',
@@ -469,6 +617,7 @@ DEFAULT_BROWSER_CONF = {
     },
 }
 
+
 def get_configured_browsers():
 
     from django.conf import settings
