@@ -1,42 +1,51 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 Conwet Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-try:
-    from django.conf.urls import patterns, include, url
-except ImportError:  # pragma: no cover
-    # for Django version less than 1.4
-    from django.conf.urls.defaults import patterns, url
+from django.conf import settings
+from django.conf.urls import patterns, include, url
+from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.cache import cache_page
+
 from wirecloud.commons.utils.template import TemplateParser
 from wirecloud.platform.markets.utils import MarketManager
 from wirecloud.platform.plugins import WirecloudPlugin, build_url_template
 
 import wirecloud.fiware
-from wirecloud.fiware.marketAdaptor.marketadaptor import MarketAdaptor
 from wirecloud.fiware.marketAdaptor.views import get_market_adaptor, get_market_user_data
 
+try:
+    from social_auth.backends import get_backends
+    IDM_SUPPORT_ENABLED = 'wirecloud.fiware' in settings.INSTALLED_APPS and 'social_auth' in settings.INSTALLED_APPS and 'fiware' in get_backends()
+except:
+    IDM_SUPPORT_ENABLED = False
+
 
 class FiWareMarketManager(MarketManager):
 
+    _user = None
+    _name = None
     _options = None
 
-    def __init__(self, options):
+    def __init__(self, user, name, options):
 
+        self._user = user
+        self._name = name
         self._options = options
 
     def search_resource(self, vendor, name, version, user):
@@ -45,8 +54,8 @@ class FiWareMarketManager(MarketManager):
     def download_resource(self, user, url, endpoint):
 
         store = endpoint['store']
-        adaptor = get_market_adaptor(None, self._options['name'])
-        user_data = get_market_user_data(user, self._options['user'], self._options['name'])
+        adaptor = get_market_adaptor(self._user, self._name)
+        user_data = get_market_user_data(user, self._user, self._name)
         storeclient = adaptor.get_store(store)
 
         store_token_key = store + '/token'
@@ -71,8 +80,8 @@ class FiWareMarketManager(MarketManager):
         }
 
         store = endpoint['store']
-        adaptor = get_market_adaptor(self._options.get('user', None), self._options['name'])
-        user_data = get_market_user_data(user, self._options['user'], self._options['name'])
+        adaptor = get_market_adaptor(self._user, self._name)
+        user_data = get_market_user_data(user, self._user, self._name)
         storeclient = adaptor.get_store(store)
 
         store_token_key = store + '/token'
@@ -82,7 +91,7 @@ class FiWareMarketManager(MarketManager):
             token = user_data['idm_token']
 
         storeclient.upload_resource(
-            resource_info['display_name'],
+            resource_info['title'],
             resource_info['version'],
             "_".join((resource_info['vendor'], resource_info['name'], resource_info['version'])) + '.wgt',
             resource_info['description'],
@@ -95,7 +104,7 @@ class FiWareMarketManager(MarketManager):
 class FiWarePlugin(WirecloudPlugin):
 
     features = {
-        'FiWare': wirecloud.fiware.__version__,
+        'FI-WARE': wirecloud.fiware.__version__,
         'NGSI': '1.0',
         'ObjectStorage': '0.5',
     }
@@ -113,7 +122,7 @@ class FiWarePlugin(WirecloudPlugin):
             'js/NGSI/NGSIManager.js',
         )
 
-        if view == 'index':
+        if view == 'classic':
             return common + (
                 "js/wirecloud/FiWare.js",
                 "js/wirecloud/FiWare/FiWareCatalogueView.js",
@@ -128,12 +137,51 @@ class FiWarePlugin(WirecloudPlugin):
             return common
 
     def get_urls(self):
-            return patterns('',
-                (r'^api/marketAdaptor/', include('wirecloud.fiware.marketAdaptor.urls')),
+        urls = patterns('',
+            url(r'^api/marketAdaptor/', include('wirecloud.fiware.marketAdaptor.urls')),
+        )
+
+        if IDM_SUPPORT_ENABLED:
+            from wirecloud.fiware.views import oauth_discovery
+            urls += patterns('',
+                url('^.well-known/oauth$', cache_page(7 * 24 * 60 * 60)(oauth_discovery), name='oauth.discovery'),
             )
 
+        return urls
+
+    def get_platform_context_definitions(self):
+        return {
+            'fiware_version': {
+                'label': _('FI-WARE version'),
+                'description': _('FI-WARE version of the platform'),
+            },
+        }
+
+    def get_platform_context_current_values(self, user):
+        # Work around bug when running manage.py compress
+        import wirecloud.fiware
+
+        return {
+            'fiware_version': wirecloud.fiware.__version__,
+        }
+
+    def get_constants(self):
+        # Work around bug when running manage.py compress
+        import wirecloud.fiware
+
+        constants = {
+            "FIWARE_HOME": getattr(settings, "FIWARE_HOME", wirecloud.fiware.DEFAULT_FIWARE_HOME),
+            'FIWARE_PORTALS': getattr(settings, "FIWARE_PORTALS", wirecloud.fiware.DEFAULT_FIWARE_PORTALS)
+        }
+
+        if IDM_SUPPORT_ENABLED:
+            import wirecloud.fiware.social_auth_backend
+            constants["FIWARE_IDM_SERVER"] = getattr(settings, "FIWARE_IDM_SERVER", wirecloud.fiware.social_auth_backend.FILAB_IDM_SERVER),
+
+        return constants
+
     def get_templates(self, view):
-        if view == 'index':
+        if view == 'classic':
             return {
                 "fiware_marketplace_search_interface": "wirecloud/fiware/marketplace/search_interface.html",
                 "fiware_catalogue_resource_details_template": "wirecloud/fiware/marketplace/resource_details.html",
@@ -162,14 +210,33 @@ class FiWarePlugin(WirecloudPlugin):
             {'id': 'FIWARE_STORE_START_PURCHASE', 'url': build_url_template('wirecloud.fiware.store_start_purchase', ['market_user', 'market_name', 'store'])},
         )
 
-    def get_widget_api_extensions(self, view):
-        return (
-            'js/WirecloudAPI/NGSIAPI.js',
-            'js/ObjectStorage/ObjectStorageAPI.js',
-        )
+    def get_widget_api_extensions(self, view, features):
+        files = []
 
-    def get_operator_api_extensions(self, view):
-        return (
-            'js/WirecloudAPI/NGSIAPI.js',
-            'js/ObjectStorage/ObjectStorageAPI.js',
-        )
+        if 'NGSI' in features:
+            files.append('js/WirecloudAPI/NGSIAPI.js')
+
+        if 'ObjectStorage' in features:
+            files.append('js/ObjectStorage/ObjectStorageAPI.js')
+
+        return files
+
+    def get_operator_api_extensions(self, view, features):
+        files = []
+
+        if 'NGSI' in features:
+            files.append('js/WirecloudAPI/NGSIAPI.js')
+
+        if 'ObjectStorage' in features:
+            files.append('js/ObjectStorage/ObjectStorageAPI.js')
+
+        return files
+
+    def get_proxy_processors(self):
+        return ('wirecloud.fiware.proxy.IDMTokenProcessor',)
+
+    def get_django_template_context_processors(self):
+        return {
+            "FIWARE_HOME": getattr(settings, "FIWARE_HOME", wirecloud.fiware.DEFAULT_FIWARE_HOME),
+            "FIWARE_PORTALS": getattr(settings, "FIWARE_PORTALS", wirecloud.fiware.DEFAULT_FIWARE_PORTALS),
+        }
