@@ -2,19 +2,19 @@
 
 # Copyright (c) 2013 Conwet Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 """
@@ -41,7 +41,7 @@ from social_auth.utils import dsa_urlopen
 from social_auth.backends import BaseOAuth2, OAuthBackend
 
 
-FILAB_IDM_SERVER = 'https://account.lab.fi-ware.eu'
+FILAB_IDM_SERVER = 'https://account.lab.fi-ware.org'
 
 FIWARE_AUTHORIZATION_ENDPOINT = 'authorize'
 FIWARE_ACCESS_TOKEN_ENDPOINT = 'token'
@@ -86,7 +86,7 @@ class FiwareAuth(BaseOAuth2):
     REDIRECT_STATE = False
     STATE_PARAMETER = False
     SETTINGS_KEY_NAME = 'FIWARE_APP_ID'
-    SETTINGS_SECRET_NAME = 'FIWARE_API_SECRET'
+    SETTINGS_SECRET_NAME = 'FIWARE_APP_SECRET'
     SCOPE_SEPARATOR = ','
     SCOPE_VAR_NAME = 'FIWARE_EXTENDED_PERMISSIONS'
 
