@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,8 +19,7 @@
  *
  */
 
-/*jslint white: true, onevar: true, undef: true, nomen: false, eqeqeq: true, plusplus: true, bitwise: true, regexp: true, newcap: true, immed: true, strict: true */
-/*global $ */
+/*global Wirecloud*/
 
 (function () {
 
@@ -33,52 +32,17 @@
         return MAC_MIMETYPES.indexOf(mimetype) !== -1;
     };
 
-    var getURI = function getURI() {
-        return this.id;
-    };
-
     function FiWareCatalogueResource(resourceJSON_) {
 
-        ///////////////////////
-        // PRIVATE VARIABLES
-        ///////////////////////
-        var vendor = resourceJSON_.vendor,
-            name = resourceJSON_.name,
-            store = resourceJSON_.store,
-            market_name = resourceJSON_.marketName,
-            parts = resourceJSON_.parts,
-            extra_data = null,
-        ///////////////////////////
-        // CONSTRUCTOR VARIABLES
-        ///////////////////////////
-            i = 0;
-
         //////////////////////////
         // GETTERS
         /////////////////////////
 
-        this.isMashup = function(){
-            var result = false;
-
-            if (this.type === 'mashup'){
-                result = true;
-            }
-            return result;
+        this.getParts = function getParts() {
+            return resourceJSON_.parts;
         };
 
-        this.getCreator = function() {
-            return "";
-        };
-
-        this.getParts = function() {
-            return parts;
-        };
-
-        this.getLastVersion = function () {
-            return allVersions[0];
-        };
-
-        this.getId = function () {
+        this.getId = function getId() {
             return resourceJSON_.id;
         };
 
@@ -86,73 +50,36 @@
             return resourceJSON_.displayName;
         };
 
-        this.getUriImage = function () {
-            return resourceJSON_.uriImage;
-        };
-
-        this.getUriTemplate = function () {
-            return resourceJSON_.uriTemplate;
-        };
-
-        this.getPage = function () {
+        this.getPage = function getPage() {
             return resourceJSON_.page;
         };
 
-        this.getCreated = function () {
-            return resourceJSON_.created;
-        };
-
-        this.getPricing = function() {
-            return resourceJSON_.pricing;
-        };
-
-        this.getSla = function() {
-            return resourceJSON_.sla;
-        };
-        
-        this.getLegal = function() {
+        this.getLegal = function getLegal() {
             return resourceJSON_.legal;
         };
 
-        this.getMarketName = function() {
-            return market_name;
-        };
-
-        this.getExtraData = function () {
-            return extra_data;
-        };
-
-        this.getTags = function () {
-            return [];
-        };
-
-        this.getURI = function () {
-            return [vendor, name, version.text].join('/');
-        };
-
         this.isAllow = function isAllow(action) {
             return false;
         };
 
-        this.getVersion = function getVersion() {
-            return this.version;
-        };
-
         var publicationdate = null;
-        if (resourceJSON_.publicationdate != null && resourceJSON_.publicationdate != '') {
+        if (resourceJSON_.publicationdate != null && resourceJSON_.publicationdate !== '') {
             publicationdate = new Date(resourceJSON_.publicationdate);
         }
 
         Object.defineProperties(this, {
             'owner': {value: resourceJSON_.vendor},
             'name': {value: resourceJSON_.name},
-            'version': {value: new Wirecloud.Version(resourceJSON_.version, 'catalogue')},
+            'version': {value: resourceJSON_.version},
             'type': {value: resourceJSON_.type},
+            'image': {value: resourceJSON_.uriImage},
             'abstract': {value: resourceJSON_.shortDescription},
             'description': {value: resourceJSON_.longDescription},
+            'pricing': {value: resourceJSON_.pricing},
             'rating': {value: resourceJSON_.rating},
+            'sla': {value: resourceJSON_.sla},
             'state': {value: resourceJSON_.state},
-            'store': {value: store},
+            'store': {value: resourceJSON_.store},
             'usdl_url': {value: resourceJSON_.usdl_url},
             'resources': {value: resourceJSON_.resources},
             'publicationdate': {value: publicationdate}
@@ -162,23 +89,22 @@
             for (var i = 0; i < this.resources.length; i += 1) {
                 var resource = this.resources[i];
                 if (is_mac_mimetype(resource.content_type)) {
-                    var parts = resource.id.split('/');
-                    resource.vendor = parts[0];
-                    resource.name = parts[1];
-                    resource.version = new Wirecloud.Version(parts[2], 'catalogue');
-                    resource.type = MAC_TYPES[MAC_MIMETYPES.indexOf(resource.content_type)];
-                    resource.getURI = getURI;
+                    try {
+                        var parts = resource.id.split('/');
+                        resource.version = new Wirecloud.Version(parts[2], 'catalogue');
+                        resource.vendor = parts[0];
+                        resource.name = parts[1];
+                        resource.uri = resource.id;
+                        resource.type = MAC_TYPES[MAC_MIMETYPES.indexOf(resource.content_type)];
+                    } catch (error) {
+                        delete resource.version;
+                        delete resource.vendor;
+                        delete resource.name;
+                        delete resource.type;
+                    }
                 }
             }
         }
-
-        //////////////
-        // SETTERS
-        //////////////
-
-        this.setExtraData = function (extra_data_) {
-            extra_data = extra_data_;
-        };
     }
 
     window.FiWareCatalogueResource = FiWareCatalogueResource;
