@@ -1,27 +1,29 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 import json
 import os
 
+from django.contrib.auth.models import User
+from django.db import IntegrityError
 from django.db.models import Q
-from django.http import HttpResponse, HttpResponseForbidden
+from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils.translation import ugettext as _
 
@@ -58,7 +60,7 @@ class MarketCollection(Resource):
 
             result[market_key] = market_data
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json'))
@@ -66,19 +68,28 @@ class MarketCollection(Resource):
     def create(self, request):
 
         try:
-            received_data = json.loads(request.raw_post_data)
-        except ValueError, e:
+            received_data = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
-        user_entry = request.user
-        if received_data['options'].get('share', '') is True:
+        if 'user' not in received_data['options'] or received_data['options']['user'] == request.user.username:
+            user_entry = request.user
+        elif received_data['options'].get('user', None) is not None:
+            user_entry = User.objects.get(username=received_data['options']['user'])
+        else:
             user_entry = None
 
-        if user_entry is None and not request.user.is_superuser:
-            return HttpResponseForbidden()
+        if (user_entry is None or user_entry != request.user) and not request.user.is_superuser:
+            return build_error_response(request, 403, _("You don't have permissions for adding public marketplaces"))
 
-        Market.objects.create(user=user_entry, name=received_data['name'], options=json.dumps(received_data['options']))
+        if 'user' in received_data['options']:
+            del received_data['options']['user']
+
+        try:
+            Market.objects.create(user=user_entry, name=received_data['name'], options=json.dumps(received_data['options']))
+        except IntegrityError:
+            return build_error_response(request, 409, 'Market name already in use')
 
         return HttpResponse(status=201)
 
@@ -88,11 +99,11 @@ class MarketEntry(Resource):
     @authentication_required
     def delete(self, request, market, user=None):
 
-        if (user is None and not request.user.is_superuser) or (user is None and market == 'local'):
-            return HttpResponseForbidden()
+        if user is None and (not request.user.is_superuser or market == 'local'):
+            return build_error_response(request, 403, _('You are not allowed to delete this market'))
 
         if user != request.user.username and not request.user.is_superuser:
-            return HttpResponseForbidden()
+            return build_error_response(request, 403, _('You are not allowed to delete this market'))
 
         get_object_or_404(Market, user__username=user, name=market).delete()
 
@@ -109,8 +120,8 @@ class PublishService(Service):
     def process(self, request):
 
         try:
-            data = json.loads(request.raw_post_data)
-        except ValueError, e:
+            data = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
@@ -130,12 +141,12 @@ class PublishService(Service):
 
             try:
                 market_managers[market_endpoint['market']].publish(market_endpoint, wgt_file, request.user, request=request)
-            except Exception, e:
+            except Exception as e:
                 errors[market_endpoint['market']] = unicode(e)
 
         if len(errors) == 0:
             return HttpResponse(status=204)
         elif len(errors) == len(data['marketplaces']):
-            return HttpResponse(json.dumps(errors), status=502, mimetype='application/json; charset=UTF-8')
+            return HttpResponse(json.dumps(errors), status=502, content_type='application/json; charset=UTF-8')
         else:
-            return HttpResponse(json.dumps(errors), status=200, mimetype='application/json; charset=UTF-8')
+            return HttpResponse(json.dumps(errors), status=200, content_type='application/json; charset=UTF-8')
