@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -25,6 +25,10 @@ from wirecloud.commons.utils.wgt import WgtFile
 
 class Migration(DataMigration):
 
+    needed_by = (
+        ("catalogue", "0002_auto__del_field_catalogueresource_ie_compatible"),
+    )
+
     def forwards(self, orm):
         from wirecloud.catalogue import utils as catalogue_utils
         from wirecloud.platform.widget import utils as showcase_utils
