@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2008-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,43 +19,29 @@
  *
  */
 
-/*global document, window, Error, gettext, interpolate, $, Hash, Event, isElement*/
-/*global Constants, ColumnLayout, CSSPrimitiveValue, DragboardPosition, FreeLayout, FullDragboardLayout, IWidget, LayoutManagerFactory, OpManagerFactory, Wirecloud, SmartColumnLayout*/
+/*global CSSPrimitiveValue, FreeLayout, FullDragboardLayout, IWidget, LayoutManagerFactory, OpManagerFactory, Wirecloud*/
 
 (function () {
 
     "use strict";
 
     var parseTab = function parseTab(tabInfo) {
-        var curIWidget, position, icon_position, zPos, width, height, iwidget,
-            widget, widgetid, minimized, layout, refusedVersion,
-            opManager, i, readOnly;
-
-        opManager = OpManagerFactory.getInstance();
+        var curIWidget, widget, layout, i;
 
         this.currentCode = 1;
-        this.iWidgets = new Hash();
-        this.iWidgetsByCode = new Hash();
+        this.iWidgets = {};
+        this.iWidgetsByCode = {};
 
-        if (this.tab.readOnly || !this.workspace.isOwned()) {
+        if (this.tab.readOnly || this.workspace.restricted) {
             this.readOnly = true;
-            this.dragboardElement.addClassName("fixed");
+            this.dragboardElement.classList.add("fixed");
         }
 
-        // For controlling when the iwidgets are totally loaded!
         for (i = 0; i < tabInfo.iwidgets.length; i++) {
             curIWidget = tabInfo.iwidgets[i];
 
             // Get widget model
-            widget = Wirecloud.LocalCatalogue.getResourceId(curIWidget.widget);
-
-            // Parse width, height and the position of the iwidget
-            width = parseInt(curIWidget.width, 10);
-            height = parseInt(curIWidget.height, 10);
-            position = new DragboardPosition(parseInt(curIWidget.left, 10), parseInt(curIWidget.top, 10));
-            icon_position = new DragboardPosition(parseInt(curIWidget.icon_left, 10), parseInt(curIWidget.icon_top, 10));
-            zPos = parseInt(curIWidget.zIndex, 10);
-            readOnly = curIWidget.readOnly;
+            widget = this.workspace.resources.getResourceId(curIWidget.widget);
 
             // Parse layout field
             if (curIWidget.layout === 0) {
@@ -65,20 +51,21 @@
             }
 
             // Create instance model
-            iwidget = new IWidget(widget,
-                                  curIWidget.id,
-                                  curIWidget.name,
-                                  layout,
-                                  position,
-                                  icon_position,
-                                  zPos,
-                                  width,
-                                  height,
-                                  curIWidget.fulldragboard,
-                                  curIWidget.minimized,
-                                  curIWidget.refused_version,
-                                  false,
-                                  readOnly);
+            new IWidget(widget,
+                curIWidget.id,
+                curIWidget.name,
+                layout,
+                new Wirecloud.DragboardPosition(curIWidget.left, curIWidget.top),
+                new Wirecloud.DragboardPosition(curIWidget.icon_left, curIWidget.icon_top),
+                curIWidget.zIndex,
+                curIWidget.width,
+                curIWidget.height,
+                curIWidget.fulldragboard,
+                curIWidget.minimized,
+                curIWidget.refused_version,
+                curIWidget.readOnly,
+                curIWidget.variables
+            );
         }
     };
 
@@ -96,12 +83,10 @@
         this.baseLayout = null;
         this.freeLayout = null;
         this.widgetToMove = null;
-        this.iWidgets = new Hash();
-        this.iWidgetsByCode = new Hash();
+        this.iWidgets = {};
+        this.iWidgetsByCode = {};
         this.tab = tab;
-        this.tabId = tab.tabInfo.id;
         this.workspace = workspace;
-        this.workspaceId = workspace.workspaceState.id;
         this.readOnly = false;
 
         // ***********************
@@ -113,7 +98,7 @@
          */
         this._commitChanges = function _commitChanges(keys) {
             var onSuccess, onError;
-            keys = keys || this.iWidgetsByCode.keys();
+            keys = keys || Object.keys(this.iWidgetsByCode);
 
             onSuccess = function (transport) { };
 
@@ -126,12 +111,12 @@
             data = [];
 
             for (var i = 0; i < keys.length; i++) {
-                iWidget = this.iWidgetsByCode.get(keys[i]);
+                iWidget = this.iWidgetsByCode[keys[i]];
                 iWidgetInfo = {};
                 position = iWidget.getPosition();
                 iWidgetInfo.id = iWidget.id;
-                iWidgetInfo.tab = this.tabId;
-                if (this.workspace.isOwned()) {
+                iWidgetInfo.tab = this.tab.id;
+                if (!this.workspace.restricted) {
                     iWidgetInfo.minimized = iWidget.isMinimized();
                 }
                 if (!iWidget.isInFullDragboardMode()) {
@@ -155,13 +140,14 @@
             }
 
             uri = Wirecloud.URLs.IWIDGET_COLLECTION.evaluate({
-                workspace_id: this.workspaceId,
-                tab_id: this.tabId
+                workspace_id: this.workspace.id,
+                tab_id: this.tab.id
             });
             Wirecloud.io.makeRequest(uri, {
                 method: 'PUT',
+                requestHeaders: {'Accept': 'application/json'},
                 contentType: 'application/json',
-                postBody: Object.toJSON(data),
+                postBody: JSON.stringify(data),
                 onSuccess: onSuccess,
                 onFailure: onError
             });
@@ -177,9 +163,9 @@
             var horizontal_margin = this.tab.preferences.get('horizontal-margin');
 
             if (this.tab.preferences.get('smart')) {
-                return new SmartColumnLayout(this, columns, cell_height, vertical_margin, horizontal_margin);
+                return new Wirecloud.ui.SmartColumnLayout(this, columns, cell_height, vertical_margin, horizontal_margin);
             } else {
-                return new ColumnLayout(this, columns, cell_height, vertical_margin, horizontal_margin);
+                return new Wirecloud.ui.ColumnLayout(this, columns, cell_height, vertical_margin, horizontal_margin);
             }
         };
 
@@ -241,11 +227,11 @@
          */
         Dragboard.prototype.addInstance = function addInstance(widget, options_) {
             var options = {
-                "iwidgetName": widget.display_name,
+                "iwidgetName": widget.title,
                 "setDefaultValues" : function () {}
             };
 
-            Object.extend(options, options_);
+            Wirecloud.Utils.merge(options, options_);
 
             if (!(widget instanceof Wirecloud.Widget)) {
                 throw new TypeError();
@@ -254,7 +240,7 @@
             if (this.readOnly) {
                 var msg = gettext("The destination tab (%(tabName)s) is read only.");
                 msg = interpolate(msg, {tabName: this.tab.tabInfo.name}, true);
-                LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.WARN_MSG);
+                (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
                 return;
             }
 
@@ -262,17 +248,10 @@
             //width = layout.adaptWidth(width, width).inLU;
             var width = widget.default_width;
             var height = widget.default_height;
-            var minimized = false;
-            var freeLayoutAfterLoading = false;
-            var layout = this.baseLayout;
-
-            if (this.tab.preferences.get('layout') === "Free") {
-                minimized = false; //NOTE: this variable is useless, it could be used in the future to add widgets as icons directly
-                freeLayoutAfterLoading = true; //To change the layout to FreeLayout after loading the widget
-            }
+            var layout = this.tab.preferences.get('layout') === "Free" ? 1 : 0;
 
             // Check if the widget doesn't fit in the dragboard
-            if (layout instanceof ColumnLayout) {
+            if (layout instanceof Wirecloud.ui.ColumnLayout) {
                 var maxColumns = layout.getColumns();
                 if (width > maxColumns) {
                     // TODO warning
@@ -280,50 +259,74 @@
                 }
             }
 
-            // Create the instance
-            var iWidget = new IWidget(widget, null, options.iwidgetName, layout, null, null, null, width, height, false, minimized, null, freeLayoutAfterLoading, false);
+            var url = Wirecloud.URLs.IWIDGET_COLLECTION.evaluate({
+                tab_id: this.tab.id,
+                workspace_id: this.workspace.id
+            });
 
-            iWidget.save(options);
-        };
+            var data = JSON.stringify({
+                'widget': widget.id,
+                'width': width,
+                'height': height,
+                'name': options.iwidgetName,
+                'layout': layout
+            });
 
-        Dragboard.prototype.removeInstance = function removeInstance(iWidgetId, orderFromServer) {
-            var iwidget = this.iWidgets.get(iWidgetId);
+            Wirecloud.io.makeRequest(url, {
+                method: 'POST',
+                contentType: 'application/json',
+                requestHeaders: {'Accept': 'application/json'},
+                postBody: data,
+                onSuccess: function onSuccess(response) {
+                    var iwidgetinfo, widget, layout, iwidget;
 
-            iwidget.remove(orderFromServer);
-        };
+                    iwidgetinfo = JSON.parse(response.responseText);
 
-        Dragboard.prototype.saveConfig = function saveConfig(iWidgetId) {
-            var iwidget = this.iWidgets.get(iWidgetId);
-            try {
-                iwidget.saveConfig();
+                    // Get widget model
+                    widget = Wirecloud.LocalCatalogue.getResourceId(iwidgetinfo.widget);
 
-                iwidget.setConfigurationVisible(false);
-            } catch (e) {
-            }
-        };
+                    // Parse layout field
+                    if (iwidgetinfo.layout === 0) {
+                        layout = this.baseLayout;
+                    } else {
+                        layout = this.freeLayout;
+                    }
 
-        Dragboard.prototype.setDefaultPrefs = function setDefaultPrefs(iWidgetId) {
-            var iwidget = this.iWidgets.get(iWidgetId);
-            iwidget.setDefaultPrefs();
-        };
-
-        Dragboard.prototype.notifyErrorOnIWidget = function notifyErrorOnIWidget(iWidgetId) {
-            var iwidget = this.iWidgets.get(iWidgetId);
-            iwidget.notifyError();
+                    iwidget = new IWidget(widget,
+                        iwidgetinfo.id,
+                        iwidgetinfo.name,
+                        layout,
+                        new Wirecloud.DragboardPosition(iwidgetinfo.left, iwidgetinfo.top),
+                        new Wirecloud.DragboardPosition(iwidgetinfo.icon_left, iwidgetinfo.icon_top),
+                        iwidgetinfo.zIndex,
+                        iwidgetinfo.width,
+                        iwidgetinfo.height,
+                        iwidgetinfo.fulldragboard,
+                        iwidgetinfo.minimized,
+                        iwidgetinfo.refused_version,
+                        iwidgetinfo.readOnly,
+                        iwidgetinfo.variables
+                    );
+                    this.addIWidget(iwidget, iwidgetinfo, options);
+                    iwidget.paint();
+                }.bind(this),
+                onFailure: function (response) {
+                    Wirecloud.GlobalLogManager.formatAndLog(gettext("Error adding iwidget to persistence: %(errorMsg)s."), response);
+                }
+            });
         };
 
         Dragboard.prototype.getIWidgets = function getIWidgets() {
-            return this.iWidgets.values();
+            return Wirecloud.Utils.values(this.iWidgets);
         };
 
         Dragboard.prototype.getIWidget = function getIWidget(iWidgetId) {
-            return this.iWidgets.get(iWidgetId);
+            return this.iWidgets[iWidgetId];
         };
 
         Dragboard.prototype.hasReadOnlyIWidgets = function hasReadOnlyIWidgets() {
-            var iwidgetKeys = this.iWidgets.keys();
-            for (var i = 0; i < iwidgetKeys.length; i++) {
-                if (this.iWidgets.get(iwidgetKeys[i]).internal_iwidget.readOnly) {
+            for (var key in this.iWidgets) {
+                if (this.iWidgets[key].internal_iwidget.readOnly) {
                     return true;
                 }
             }
@@ -338,12 +341,12 @@
          */
         Dragboard.prototype._registerIWidget = function _registerIWidget(iWidget) {
             if (iWidget.id) {
-                this.iWidgets.set(iWidget.id, iWidget);
+                this.iWidgets[iWidget.id] = iWidget;
             }
 
             iWidget.code = this.currentCode++;
 
-            this.iWidgetsByCode.set(iWidget.code, iWidget);
+            this.iWidgetsByCode[iWidget.code] = iWidget;
             var zpos = iWidget.getZPosition();
             if (zpos !== null) {
                 if (this.orderList[zpos] !== undefined) {
@@ -372,8 +375,8 @@
          * @param iWidget the iWidget to register
          */
         Dragboard.prototype._deregisterIWidget = function _deregisterIWidget(iWidget) {
-            this.iWidgets.unset(iWidget.id);
-            this.iWidgetsByCode.unset(iWidget.code);
+            delete this.iWidgets[iWidget.id];
+            delete this.iWidgetsByCode[iWidget.code];
 
             // Update z order List
             var zpos = iWidget.getZPosition();
@@ -388,7 +391,7 @@
         };
 
         Dragboard.prototype.addIWidget = function addIWidget(iWidget, iwidgetInfo, options) {
-            if (!this.iWidgetsByCode.get(iWidget.code)) {
+            if (!this.iWidgetsByCode[iWidget.code]) {
                 throw new Error();
             }
 
@@ -400,7 +403,7 @@
             // Notify resize event
             iWidget.layout._notifyResizeEvent(iWidget, oldWidth, oldHeight, iWidget.getWidth(), iWidget.getHeight(), false, true);
 
-            this.iWidgets.set(iWidget.id, iWidget);
+            this.iWidgets[iWidget.id] = iWidget;
         };
 
         Dragboard.prototype.fillFloatingWidgetsMenu = function fillFloatingWidgetsMenu(menu) {
@@ -409,8 +412,8 @@
 
         Dragboard.prototype.lowerToBottom = function lowerToBottom(iWidget) {
             var zPos = iWidget.getZPosition();
-            delete this.orderList[zPos];
-            this.orderList = [iWidget].concat(this.orderList).compact();
+            this.orderList.splice(zPos, 1);
+            this.orderList = [iWidget].concat(this.orderList);
 
             for (var i = 0; i < this.orderList.length; i++) {
                 this.orderList[i].setZPosition(i);
@@ -444,12 +447,10 @@
                 return; // Nothing to do
             }
 
-            delete this.orderList[oldZPos];
+            this.orderList.splice(oldZPos, 1);
             this.orderList.push(iWidget);
-            this.orderList = this.orderList.compact();
 
-            var i = 0;
-            for (; i < this.orderList.length; i++) {
+            for (var i = oldZPos; i < this.orderList.length; i++) {
                 this.orderList[i].setZPosition(i);
             }
 
@@ -521,7 +522,7 @@
 
         // Check if we have to readjust the z positions
         oldLength = this.orderList.length;
-        this.orderList = this.orderList.compact();
+        this.orderList = this.orderList.filter(function (iwidget) { return iwidget != null; });
         if (oldLength !== this.orderList.length) {
             for (i = 0; i < this.orderList.length; i += 1) {
                 this.orderList[i].setZPosition(i);
@@ -588,105 +589,13 @@
 
 })();
 
-/////////////////////////////////////
-// DragboardPosition
-/////////////////////////////////////
-function DragboardPosition(x, y) {
-    this.x = x;
-    this.y = y;
-}
-
-DragboardPosition.prototype.clone = function () {
-    return new DragboardPosition(this.x, this.y);
-};
-
-/////////////////////////////////////
-// DragboardCursor
-/////////////////////////////////////
-
-/**
- * @class This class represents a dragboard cursor. It is usually used in drag
- *        & drop operations and always represents the place where an iWidget is
- *        going to be placed.
- *
- * @author Álvaro Arranz
- *
- * @param iWidget iWidget that is going to be represented by the new dragboard
- *                cursor
- */
-function DragboardCursor(iWidget) {
-    this.refIWidget = iWidget;
-
-    var positiontmp = iWidget.getPosition();
-    this.position = positiontmp.clone();
-
-    this.layout = iWidget.layout;
-    this.width = iWidget.getWidth();
-    this.height = iWidget.getHeight();
-    this.heightInPixels = iWidget.element.offsetHeight;
-    this.widthInPixels = iWidget.element.offsetWidth;
-}
-
-DragboardCursor.prototype.getWidth = function () {
-    return this.width;
-};
-
-DragboardCursor.prototype.getHeight = function () {
-    return this.height;
-};
-
-DragboardCursor.prototype.paint = function (dragboard) {
-    var dragboardCursor = document.createElement("div");
-    dragboardCursor.setAttribute("id", "dragboardcursor");
-
-    // Set width and height
-    dragboardCursor.style.height = this.heightInPixels + "px";
-    dragboardCursor.style.width = this.widthInPixels + "px";
-
-    // Set position
-    dragboardCursor.style.left = (this.layout.getColumnOffset(this.position.x) - 2) + "px"; // TODO -2 px for borders
-    dragboardCursor.style.top = (this.layout.getRowOffset(this.position.y) - 2) + "px"; // TODO -2 px for borders
-
-    dragboardCursor.style.zIndex = this.refIWidget.getZPosition();
-
-    // assign the created element
-    dragboard.insertBefore(dragboardCursor, this.refIWidget.element);
-    this.element = dragboardCursor;
-};
-
-/**
- * This method must be called to avoid memory leaks caused by circular
- * references.
- */
-DragboardCursor.prototype.destroy = function () {
-    if (isElement(this.element)) {
-        this.element.parentNode.removeChild(this.element);
-        this.element = null;
-    }
-};
-
-DragboardCursor.prototype.getWidth = function () {
-    return this.width;
-};
-
-DragboardCursor.prototype.getPosition = IWidget.prototype.getPosition;
-
-DragboardCursor.prototype.setPosition = function (position) {
-    this.position = position;
-
-    if (this.element !== null) { // if visible
-        this.element.style.left = (this.layout.getColumnOffset(position.x) - 2) + "px"; // TODO -2 px for borders
-        this.element.style.top = (this.layout.getRowOffset(position.y) - 2) + "px"; // TODO -2 px for borders
-    }
-};
-
 /////////////////////////////////////
 // Drag and drop support
 /////////////////////////////////////
 var EzWebEffectBase = {};
 EzWebEffectBase.findDragboardElement = function (element) {
     var tmp = element.parentNode;
-    while (isElement(tmp)) {
+    while (Wirecloud.Utils.XML.isElement(tmp)) {
         //var position = tmp.getStyle("position");
         var position = document.defaultView.getComputedStyle(tmp, null).getPropertyValue("position");
         switch (position) {
@@ -701,157 +610,6 @@ EzWebEffectBase.findDragboardElement = function (element) {
     return null; // Not found
 };
 
-/////////////////////////////////////
-// IWidget drag & drop support
-/////////////////////////////////////
-function IWidgetDraggable(iWidget) {
-    var context = {
-        iWidget: iWidget
-    };
-    Draggable.call(this, iWidget.widgetMenu, context,
-                         IWidgetDraggable.prototype.startFunc,
-                         IWidgetDraggable.prototype.updateFunc,
-                         IWidgetDraggable.prototype.finishFunc,
-                         IWidgetDraggable.prototype.canBeDraggedFunc);
-
-    this.setXOffset = function (xOffset) {
-        context.xOffset = xOffset;
-    };
-
-    this.setYOffset = function (yOffset) {
-        context.yOffset = yOffset;
-    };
-}
-
-IWidgetDraggable.prototype.canBeDraggedFunc = function (draggable, context) {
-    return context.iWidget.isAllowed('move') && !(context.iWidget.layout instanceof FullDragboardLayout);
-};
-
-
-IWidgetDraggable.prototype.startFunc = function (draggable, context) {
-    context.selectedTab = null;
-    context.selectedTabElement = null;
-    context.layout = context.iWidget.layout;
-    context.dragboard = context.layout.dragboard;
-    context.currentTab = context.dragboard.tabId;
-    context.dragboard.raiseToTop(context.iWidget);
-    context.layout.initializeMove(context.iWidget, draggable);
-
-    context.y = context.iWidget.element.style.top === "" ? 0 : parseInt(context.iWidget.element.style.top, 10);
-    context.x = context.iWidget.element.style.left === "" ? 0 : parseInt(context.iWidget.element.style.left, 10);
-
-    return {
-        dragboard: EzWebEffectBase.findDragboardElement(context.iWidget.element)
-    };
-};
-
-IWidgetDraggable.prototype._findTabElement = function (curNode, maxRecursion) {
-    if (maxRecursion === 0) {
-        return null;
-    }
-
-    // Only check elements, skip other dom nodes.
-    if (isElement(curNode) && curNode.hasClassName('tab')) {
-        return curNode;
-    } else {
-        var parentNode = curNode.parentNode;
-        if (isElement(parentNode)) {
-            return this._findTabElement(parentNode, maxRecursion - 1);
-        } else {
-            return null;
-        }
-    }
-};
-
-IWidgetDraggable.prototype.updateFunc = function (event, draggable, context, xDelta, yDelta) {
-    var x, y, element = null;
-
-    context.iWidget.element.style.left = (context.x + xDelta) + 'px';
-    context.iWidget.element.style.top = (context.y + yDelta) + 'px';
-
-    x = context.x + xDelta + context.xOffset;
-    y = context.y + yDelta + context.yOffset;
-
-    // Check if the mouse is over a tab
-    element = document.elementFromPoint(event.clientX, event.clientY);
-    if (element !== null) {
-        // elementFromPoint may return inner tab elements
-        element = draggable._findTabElement(element, 4);
-    }
-
-    var id = null;
-    if (element !== null) {
-        id = element.getAttribute("id");
-
-        if (id !== null) {
-            var result = id.match(/tab_(\d+)_(\d+)/);
-            if (result !== null && result[2] !== context.currentTab) {
-                if (context.selectedTab === result[2]) {
-                    return;
-                }
-
-                if (context.selectedTabElement !== null) {
-                    context.selectedTabElement.removeClassName("selected");
-                }
-
-                context.selectedTab = result[2];
-                context.selectedTabElement = element;
-                context.selectedTabElement.addClassName("selected");
-                context.layout.disableCursor();
-                return;
-            }
-        }
-    }
-
-    // The mouse is not over a tab
-    // The cursor must allways be inside the dragboard
-    var position = context.layout.getCellAt(x, y);
-    if (position.y < 0) {
-        position.y = 0;
-    }
-    if (position.x < 0) {
-        position.x = 0;
-    }
-    if (context.selectedTabElement !== null) {
-        context.selectedTabElement.removeClassName("selected");
-    }
-    context.selectedTab = null;
-    context.selectedTabElement = null;
-    context.layout.moveTemporally(position.x, position.y);
-    return;
-};
-
-IWidgetDraggable.prototype.finishFunc = function (draggable, context) {
-    var tab, destDragboard, workspace, destLayout;
-    if (context.selectedTab !== null) {
-        context.layout.cancelMove();
-
-        workspace = context.dragboard.workspace;
-        tab = workspace.getTab(context.selectedTab);
-
-        // On-demand loading of tabs!
-        tab.paint();
-        destDragboard = tab.getDragboard();
-
-        if (context.iWidget.onFreeLayout()) {
-            destLayout = destDragboard.freeLayout;
-        } else {
-            destLayout = destDragboard.baseLayout;
-        }
-
-        context.iWidget.moveToLayout(destLayout);
-
-        workspace.highlightTab(parseInt(context.selectedTab, 10));
-
-        context.selectedTab = null;
-        context.selectedTabElement = null;
-    } else {
-        context.layout.acceptMove();
-    }
-
-    context.dragboard = null;
-};
-
 
 /////////////////////////////////////
 // IWidget Icon drag & drop support
@@ -862,7 +620,7 @@ function IWidgetIconDraggable(iWidget) {
         x: null,
         y: null
     };
-    Draggable.call(this, iWidget.iconImg, context,
+    Wirecloud.ui.Draggable.call(this, iWidget.iconImg, context,
                          IWidgetIconDraggable.prototype.startFunc,
                          IWidgetIconDraggable.prototype.updateFunc,
                          IWidgetIconDraggable.prototype.finishFunc,
