@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,31 +19,19 @@
  *
  */
 
-/*global StyledElements, Wirecloud*/
+/*global gettext, interpolate, Tab, StyledElements, Wirecloud*/
 
 (function () {
 
     "use strict";
 
-    var old_context_api_adaptor_callback = function old_context_api_adaptor_callback(new_values) {
-        var key, variables;
-
-        variables = this.workspace.varManager.getIWidgetVariables(this.id);
-        for (key in variables) {
-            var variable = variables[key];
-            if (variable.vardef.aspect === 'GCTX' && variable.vardef.concept in new_values) {
-                variable.annotate(new_values[variable.vardef.concept]);
-                variable.set(new_values[variable.vardef.concept]);
-            }
-        }
-    };
-
     var renameSuccess = function renameSuccess(options, old_name, new_name, response) {
         this.name = new_name;
+        this.contextManager.modify({title: new_name});
 
         var msg = gettext("Name changed from \"%(oldName)s\" to \"%(newName)s\" succesfully");
         msg = interpolate(msg, {oldName: old_name, newName: new_name}, true);
-        this.logManager.log(msg, Constants.Logging.INFO_MSG);
+        this.logManager.log(msg, Wirecloud.constants.LOGGING.INFO_MSG);
 
         this.events.name_changed.dispatch(new_name);
 
@@ -56,7 +44,7 @@
 
     var renameFailure = function renameFailure(options, response) {
         var msg = gettext("Error renaming iwidget from persistence: %(errorMsg)s.");
-        msg = this.internal_iwidget.logManager.formatError(msg, transport, e);
+        msg = this.logManager.formatError(msg, response);
         this.log(msg);
 
         if (options.onFailure === 'function') {
@@ -66,11 +54,39 @@
         }
     };
 
+    var removeSuccess = function removeSuccess(options, response) {
+        var msg = gettext("IWidget \"%(name)s\" removed from workspace succesfully");
+        msg = interpolate(msg, {name: this.name}, true);
+        this.logManager.log(msg, Wirecloud.constants.LOGGING.INFO_MSG);
+
+        this.events.removed.dispatch(this);
+
+        if (options.onSuccess === 'function') {
+            try {
+                options.onSuccess();
+            } catch (e) {}
+        }
+
+        this.destroy();
+    };
+
+    var removeFailure = function removeFailure(options, response) {
+        var msg = gettext("Error removing iwidget from persistence: %(errorMsg)s.");
+        msg = this.logManager.formatError(msg, response);
+        this.logManager.log(msg);
+
+        if (options.onFailure === 'function') {
+            try {
+                options.onFailure(msg);
+            } catch (e) {}
+        }
+    };
+
     /**
      */
     var IWidget = function IWidget(widget, tab, options) {
 
-        var key;
+        var key, i, preferences, iwidget_pref_info, properties, iwidget_prop_info;
 
         if (typeof options !== 'object' || !(widget instanceof Wirecloud.Widget)) {
             throw new TypeError();
@@ -99,29 +115,82 @@
             this.outputs[key] = new Wirecloud.wiring.WidgetSourceEndpoint(this, this.meta.outputs[key]);
         }
 
+        preferences = this.meta.preferenceList;
+        this.preferenceList = [];
+        this.preferences = {};
+        if (options.variables != null) {
+            for (i = 0; i < preferences.length; i++) {
+                iwidget_pref_info = options.variables[preferences[i].name];
+                this.preferenceList[i] = new Wirecloud.UserPref(preferences[i], iwidget_pref_info.readonly, iwidget_pref_info.hidden, iwidget_pref_info.value);
+                this.preferences[preferences[i].name] = this.preferenceList[i];
+            }
+        }
+
+        properties = this.meta.propertyList;
+        this.propertyList = [];
+        this.properties = {};
+        if (options.variables != null) {
+            for (i = 0; i < properties.length; i++) {
+                iwidget_prop_info = options.variables[properties[i].name];
+                this.propertyList[i] = new Wirecloud.PersistentVariable(properties[i], iwidget_prop_info.id, iwidget_prop_info.readonly, iwidget_prop_info.value);
+                this.properties[properties[i].name] = this.propertyList[i];
+            }
+        }
+
         this.callbacks = {
             'iwidget': [],
             'mashup': [],
             'platform': []
         };
         this.contextManager = new Wirecloud.ContextManager(this, {
-            'xPosition': 0,
-            'yPosition': 0,
-            'height': 0,
-            'width': 0,
-            'heightInPixels': 0,
-            'widthInPixels': 0
+            'title': {
+                label: gettext("Title"),
+                description: gettext("Widget's title"),
+                value: options.name
+            },
+            'xPosition': {
+                label: gettext("X-Position"),
+                description: gettext("Specifies the x-coordinate at which the widget is placed"),
+                value: 0
+            },
+            'yPosition': {
+                label: gettext("Y-Position"),
+                description: gettext("Specifies the y-coordinate at which the widget is placed"),
+                value: 0
+            },
+            'height': {
+                label: gettext("Height"),
+                description: gettext("Widget's height in layout cells"),
+                value: 0
+            },
+            'width': {
+                label: gettext("Width"),
+                description: gettext("Widget's width in layout cells"),
+                value: 0
+            },
+            'heightInPixels': {
+                label: gettext("Height in pixels"),
+                description: gettext("Widget's height in pixels"),
+                value: 0
+            },
+            'widthInPixels': {
+                label: gettext("Width in pixels"),
+                description: gettext("Widget's width in pixels"),
+                value: 0
+            }
         });
-        this._old_context_api_adaptor_callback = old_context_api_adaptor_callback.bind(this);
-        this.contextManager.addCallback(this._old_context_api_adaptor_callback);
-        this.logManager = new Wirecloud.Widget.LogManager(this);
+        Object.defineProperty(this, 'logManager', {value: new Wirecloud.Widget.LogManager(this)});
         this.prefCallback = null;
 
-        StyledElements.ObjectWithEvents.call(this, ['load', 'unload', 'name_changed']);
+        StyledElements.ObjectWithEvents.call(this, ['load', 'unload', 'removed', 'name_changed']);
     };
     IWidget.prototype = new StyledElements.ObjectWithEvents();
 
     IWidget.prototype.isAllowed = function isAllowed(action) {
+        if (this.workspace.restricted) {
+            return false;
+        }
+
         switch (action) {
         case "close":
             return !this.readOnly && this.workspace.isAllowed('add_remove_iwidgets');
@@ -130,22 +199,14 @@
             return !this.tab.readOnly && this.workspace.isAllowed('edit_layout');
         case "minimize":
             return this.workspace.isAllowed('edit_layout');
+        case "rename":
+        case "configure":
+            return true;
         default:
             return false;
         }
     };
 
-    IWidget.prototype.getVariable = function getVariable(name) {
-        var variable;
-
-        variable = this.workspace.varManager.findVariable(this.id, name);
-        if (variable.vardef.aspect === 'PROP') {
-            return variable;
-        } else {
-            return null;
-        }
-    };
-
     IWidget.prototype.registerPrefCallback = function registerPrefCallback(prefCallback) {
         this.prefCallback = prefCallback;
     };
@@ -159,7 +220,7 @@
             this.workspace.contextManager.addCallback(callback);
             break;
         case 'platform':
-            OpManagerFactory.getInstance().contextManager.addCallback(callback);
+            Wirecloud.contextManager.addCallback(callback);
             break;
         default:
             throw new TypeError('invalid scope');
@@ -174,14 +235,12 @@
      * @private
      */
     IWidget.prototype._notifyLoaded = function _notifyLoaded(element) {
-        var msg;
 
-        if (this.loaded || !element.hasAttribute('src') ) {
+        if (this.loaded || !element.hasAttribute('src')) {
             return;
         }
 
-        msg = gettext('iWidget loaded');
-        this.logManager.log(msg, Constants.Logging.INFO_MSG);
+        this.logManager.log(gettext('iWidget loaded'), Wirecloud.constants.LOGGING.INFO_MSG);
 
         this.loaded = true;
 
@@ -195,18 +254,17 @@
         }
         this.pending_events = [];
 
-        this.events['load'].dispatch(this);
+        this.events.load.dispatch(this);
     };
 
     IWidget.prototype._notifyUnloaded = function _notifyUnloaded() {
-        var i, opManager;
+        var i;
 
         if (!this.loaded) {
             return;
         }
 
-        var msg = gettext('iWidget unloaded');
-        this.logManager.log(msg, Constants.Logging.INFO_MSG);
+        this.logManager.log(gettext('iWidget unloaded'), Wirecloud.constants.LOGGING.INFO_MSG);
         this.logManager.newCycle();
 
         // Remove context callbacks
@@ -218,9 +276,8 @@
             this.workspace.contextManager.removeCallback(this.callbacks.mashup[i]);
         }
 
-        opManager = OpManagerFactory.getInstance();
         for (i = 0; i < this.callbacks.platform.length; i += 1) {
-            opManager.contextManager.removeCallback(this.callbacks.platform[i]);
+            Wirecloud.contextManager.removeCallback(this.callbacks.platform[i]);
         }
 
         this.callbacks = {
@@ -233,7 +290,7 @@
         this.prefCallback = null;
 
         this.loaded = false;
-        this.events['unload'].dispatch(this);
+        this.events.unload.dispatch(this);
     };
 
     IWidget.prototype.buildInterface = function buildInterface(template, view) {
@@ -268,13 +325,14 @@
 
         if (new_name !== null && new_name.length > 0) {
             var iwidgetUrl = Wirecloud.URLs.IWIDGET_ENTRY.evaluate({
-                workspace_id: this.workspace.getId(),
-                tab_id: this.tab.getId(),
+                workspace_id: this.workspace.id,
+                tab_id: this.tab.id,
                 iwidget_id: this.id
             });
             Wirecloud.io.makeRequest(iwidgetUrl, {
                 method: 'POST',
                 contentType: 'application/json',
+                requestHeaders: {'Accept': 'application/json'},
                 postBody: JSON.stringify({name: new_name}),
                 onSuccess: renameSuccess.bind(this, options, old_name, new_name),
                 onFailure: renameFailure.bind(this, options)
@@ -282,6 +340,26 @@
         }
     };
 
+    IWidget.prototype.remove = function remove(options) {
+        var url;
+
+        if (options == null) {
+            options = {};
+        }
+
+        url = Wirecloud.URLs.IWIDGET_ENTRY.evaluate({
+            workspace_id: this.workspace.id,
+            tab_id: this.tab.id,
+            iwidget_id: this.id
+        });
+        Wirecloud.io.makeRequest(url, {
+            method: 'DELETE',
+            requestHeaders: {'Accept': 'application/json'},
+            onSuccess: removeSuccess.bind(this, options),
+            onFailure: removeFailure.bind(this, options)
+        });
+    };
+
     /**
      * This method must be called to avoid memory leaks caused by circular references.
      */
@@ -289,14 +367,13 @@
 
         if (this.loaded) {
             this.events.unload.dispatch(this);
+            this.loaded = false;
         }
 
-        this.workspace.varManager.removeInstance(this.id);
-        this.contextManager.removeCallback(this._old_context_api_adaptor_callback);
         this.contextManager = null;
         this.logManager.close();
-        this.logManager = null;
     };
 
     Wirecloud.IWidget = IWidget;
+
 })();
