@@ -48,7 +48,7 @@
 
     SourceEndpoint.prototype.fullDisconnect = function fullDisconnect() {
         // Outputs
-        var outputs = this.outputs.clone();
+        var outputs = Wirecloud.Utils.clone(this.outputs);
         for (var i = 0; i < outputs.length; ++i) {
             this.disconnect(outputs[i]);
         }
@@ -61,14 +61,10 @@
     SourceEndpoint.prototype.propagate = function propagate(value, options) {
         var i;
 
-        options = Object.extend({
+        options = Wirecloud.Utils.merge({
             initial: false
         }, options);
 
-        for (i = 0; i < this.outputs.length; ++i) {
-            this.outputs[i]._annotate(value, this, options);
-        }
-
         for (i = 0; i < this.outputs.length; ++i) {
             this.outputs[i].propagate(value, options);
         }
