@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -18,12 +18,44 @@
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import os
 import time
+import urlparse
+import urllib
 
+from selenium.common.exceptions import NoSuchElementException, StaleElementReferenceException
+from selenium.webdriver.common.action_chains import ActionChains
+from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 
 from wirecloud.catalogue.models import CatalogueResource
-from wirecloud.commons.utils.testcases import uses_extra_resources, WirecloudSeleniumTestCase
+from wirecloud.commons.utils.testcases import uses_extra_resources, MobileWirecloudSeleniumTestCase, WirecloudSeleniumTestCase, wirecloud_selenium_test_case
+
+
+def element_to_be_clickable(selector, base_element=None):
+
+    def wrapper(driver):
+
+        try:
+            if base_element is not None:
+                element = base_element.find_element(*selector)
+            else:
+                element = driver.find_element(*selector)
+            position = element.location
+            top_element = driver.execute_script('return document.elementFromPoint(arguments[0], arguments[1]);',
+                    position['x'] + (element.size['width'] / 2),
+                    position['y'] + (element.size['height'] / 2)
+                )
+
+            while top_element is not None:
+                if element == top_element:
+                    return element
+                top_element = top_element.find_element_by_xpath('..')
+            return False
+        except (NoSuchElementException, StaleElementReferenceException):
+            return False
+
+    return wrapper
 
 
 class BasicSeleniumTests(WirecloudSeleniumTestCase):
@@ -36,7 +68,7 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
 
         # We need atleast one Workspace, so we cannot delete current workspace
         self.driver.find_element_by_css_selector('#wirecloud_breadcrum .second_level > .icon-menu').click()
-        self.check_popup_menu(('Rename', 'Settings', 'New workspace', 'Upload to local catalogue'), ('Remove',))
+        self.check_popup_menu(('Rename', 'Settings', 'New workspace', 'Upload to local catalogue'), must_be_disabled=('Remove',))
 
         self.create_workspace('Test')
 
@@ -73,9 +105,31 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
 
         # Now we have only one workspace, so we cannot remove it
         self.driver.find_element_by_css_selector('#wirecloud_breadcrum .second_level > .icon-menu').click()
-        self.check_popup_menu(('Rename', 'Settings', 'New workspace'), ('Remove',))
+        self.check_popup_menu(('Rename', 'Settings', 'New workspace'), must_be_disabled=('Remove',))
     test_basic_workspace_operations.tags = ('fiware-ut-5',)
 
+    def test_move_iwidget_between_tabs(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_current_workspace('Pending Events')
+
+        src_tab_iwidgets = self.get_current_iwidgets(tab=102)
+        dst_tab_iwidgets = self.get_current_iwidgets(tab=103)
+        src_iwidget_count = len(src_tab_iwidgets)
+        dst_iwidget_count = len(dst_tab_iwidgets)
+
+        iwidget = src_tab_iwidgets[0]
+
+        handle = iwidget.element.find_element_by_css_selector('.widget_menu')
+        tab = self.get_workspace_tab_by_name('Tab 2')
+        ActionChains(self.driver).click_and_hold(handle).move_to_element(tab).release().perform()
+
+        src_tab_iwidgets = self.get_current_iwidgets(tab=102)
+        dst_tab_iwidgets = self.get_current_iwidgets(tab=103)
+        self.assertEqual(len(src_tab_iwidgets), src_iwidget_count - 1)
+        self.assertEqual(len(dst_tab_iwidgets), dst_iwidget_count + 1)
+
     def test_add_widget_from_catalogue(self):
 
         self.login()
@@ -138,7 +192,6 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
 
         self.login(username='user_with_workspaces')
         iwidget = self.get_current_iwidgets()[0]
-        api_test_iwidget = self.add_widget_to_mashup('Wirecloud API test')
 
         with iwidget:
             self.assertEqual(self.driver.find_element_by_id('listPref').text, 'default')
@@ -197,6 +250,8 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(self.driver.find_element_by_id('passwordPref').text, '')
 
         # Use api test widget to test other API features
+        self.network._servers['http']['example.com'].add_response('GET', '/success.html', {'content': 'remote makerequest was successful'})
+        api_test_iwidget = self.add_widget_to_mashup('Wirecloud API test')
 
         # Open widget settings again
         api_test_iwidget.perform_action('Settings')
@@ -237,6 +292,11 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
             self.assertEqual(api_test_iwidget.error_count, 5)
             self.assertEqual(len(api_test_iwidget.log_entries), old_log_entries + 7)
 
+            # Work around some firefox driver bugs
+            self.driver.execute_script('arguments[0].click()', self.driver.find_element_by_css_selector('#check_preference_exceptions_button'))
+            WebDriverWait(self.driver, timeout=2).until(lambda driver: driver.find_element_by_id('preference_exceptions_test').text == 'Success!!')
+            self.assertEqual(api_test_iwidget.error_count, 7)
+            self.assertEqual(len(api_test_iwidget.log_entries), old_log_entries + 9)
     test_basic_widget_functionalities.tags = ('fiware-ut-5',)
 
     def test_pending_wiring_events(self):
@@ -552,6 +612,125 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
 
         self.assertEqual(len(self.get_current_iwidgets()), 2)
 
+    def test_public_workspaces(self):
+
+        # Make Test and TestOperator unavailable to emptyuser
+        test_widget = CatalogueResource.objects.get(short_name='Test')
+        test_widget.public = False
+        test_widget.save()
+
+        test_operator = CatalogueResource.objects.get(short_name='TestOperator')
+        test_operator.public = False
+        test_operator.save()
+
+        self.login(username='emptyuser', next='/user_with_workspaces/Public Workspace')
+
+        # Check public workspaces cannot be renamed/removed by non owners
+        self.driver.find_element_by_css_selector('#wirecloud_breadcrum .second_level > .icon-menu').click()
+        self.check_popup_menu(must_be_disabled=('Rename', 'Settings', 'Remove'))
+        self.driver.find_element_by_css_selector('#wirecloud_breadcrum .second_level > .icon-menu').click()
+
+        self.check_public_workspace()
+    test_public_workspaces.tags = ('fiware-ut-18',)
+
+    def test_public_workspaces_anonymous_user(self):
+
+        # Make Test and TestOperator unavailable to the anonymous user
+        test_widget = CatalogueResource.objects.get(short_name='Test')
+        test_widget.public = False
+        test_widget.save()
+
+        test_operator = CatalogueResource.objects.get(short_name='TestOperator')
+        test_operator.public = False
+        test_operator.save()
+
+        url = self.live_server_url + '/user_with_workspaces/Public Workspace'
+        self.driver.get(url)
+        self.wait_wirecloud_ready()
+
+        self.assertRaises(NoSuchElementException, self.driver.find_element_by_css_selector, '#wirecloud_breadcrum .second_level > .icon-menu')
+        self.assertRaises(NoSuchElementException, self.driver.find_element_by_css_selector, '#wirecloud_header .menu .workspace')
+        self.assertRaises(NoSuchElementException, self.driver.find_element_by_css_selector, '#wirecloud_header .menu .wiring')
+        self.assertRaises(NoSuchElementException, self.driver.find_element_by_css_selector, '#wirecloud_header .menu .marketplace')
+
+        self.check_public_workspace()
+
+        sign_in_button = self.driver.find_element_by_css_selector('#wirecloud_header .user_menu_wrapper .styled_button > div, #wirecloud_header .arrow-down-settings')
+        if sign_in_button.text != 'Sign in':
+            # Oiltheme
+            sign_in_button.click()
+            self.popup_menu_click('Sign in')
+        else:
+            sign_in_button.click()
+
+        username_input = self.wait_element_visible_by_css_selector('#id_username')
+        self.fill_form_input(username_input, 'user_with_workspaces')
+        password_input = self.driver.find_element_by_id('id_password')
+        self.fill_form_input(password_input, 'admin')
+        password_input.submit()
+
+        self.wait_wirecloud_ready()
+        self.assertEqual(self.get_current_workspace_name(), 'Public Workspace')
+    test_public_workspaces_anonymous_user.tags = ('fiware-ut-18',)
+
+    def test_embedded_view(self):
+
+        mashup_url = self.live_server_url + '/user_with_workspaces/Public Workspace?mode=embedded'
+        iframe_test_path = os.path.join(self.shared_test_data_dir, 'iframe_test.html')
+        iframe_test_url = urlparse.urljoin('file:', urllib.pathname2url(iframe_test_path))
+        self.driver.get(iframe_test_url)
+
+        # Load Wirecloud using the iframe element
+        self.driver.execute_script("document.getElementById('iframe').src = arguments[0]", mashup_url)
+
+        # Swicth to Wirecloud's iframe
+        iframe = self.driver.find_element_by_id('iframe')
+        self.driver.switch_to_frame(iframe)
+        self.wait_wirecloud_ready()
+        self.check_public_workspace(frame_id='iframe')
+    test_embedded_view.tags = ('fiware-ut-18',)
+
+    def check_public_workspace(self, frame_id=None):
+        # Check iwidget are loaded correctly
+        iwidgets = self.get_current_iwidgets()
+        self.assertEqual(len(iwidgets), 2)
+        source_iwidget = iwidgets[1]
+        target_iwidget = iwidgets[0]
+        self.assertIsNotNone(source_iwidget.element)
+        self.assertIsNotNone(target_iwidget.element)
+
+        source_iwidget.element.find_element_by_css_selector('.icon-cogs').click()
+        self.check_popup_menu(must_be_disabled=('Rename', 'Settings', 'Full Dragboard', 'Extract from grid'))
+
+        target_iwidget.element.find_element_by_css_selector('.icon-cogs').click()
+        self.check_popup_menu(must_be_disabled=('Rename', 'Settings', 'Full Dragboard', 'Extract from grid'))
+
+        tab = self.get_workspace_tab_by_name('Tab')
+        self.assertRaises(NoSuchElementException, tab.find_element_by_css_selector, '.icon-tab-menu')
+
+        self.assertRaises(NoSuchElementException, self.driver.find_element_by_css_selector, '.icon-add-tab')
+
+        # Check wiring works
+        with source_iwidget:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+            #self.driver.find_element_by_id('b1').click()
+
+        # Work around selenium not being able to go to the parent frame
+        if frame_id is not None:
+            self.driver.switch_to_frame(self.driver.find_element_by_id(frame_id))
+
+        with target_iwidget:
+            try:
+                WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'hello world!!')
+            except:
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'hello world!!')
+
     def test_browser_navigation_history_management(self):
 
         self.login(username='user_with_workspaces')
@@ -568,3 +747,145 @@ class BasicSeleniumTests(WirecloudSeleniumTestCase):
         WebDriverWait(self.driver, timeout=10).until(lambda driver: self.get_current_view() == 'workspace')
         self.driver.back()
         self.assertEqual(self.driver.current_url, self.live_server_url + '/login')
+
+    def test_browser_navigation_from_renamed_workspace(self):
+
+        self.login(username='user_with_workspaces')
+
+        initial_workspace = self.get_current_workspace_name()
+
+        self.change_current_workspace('Pending Events')
+        self.rename_workspace('New Name')
+
+        self.driver.back()
+        WebDriverWait(self.driver, 5, ignored_exceptions=(StaleElementReferenceException,)).until(lambda driver: self.get_current_workspace_name() == initial_workspace)
+
+    def test_browser_navigation_to_deleted_workspace(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_current_workspace('Pending Events')
+        self.remove_workspace()
+
+        self.assertEqual(self.get_current_workspace_name(), 'ExistingWorkspace')
+
+        self.driver.back()
+        WebDriverWait(self.driver, 5, ignored_exceptions=(StaleElementReferenceException,)).until(lambda driver: self.get_current_workspace_name() == 'Pending Events')
+        self.driver.back()
+        WebDriverWait(self.driver, 5, ignored_exceptions=(StaleElementReferenceException,)).until(lambda driver: self.get_current_workspace_name() == 'Workspace')
+
+    def assertElementHasFocus(self, element):
+        # Workaround webkit problem with xhtml and retreiving element with focus
+        if self.driver.capabilities['browserName'] == 'chrome':
+            return
+        focused_element = self.driver.switch_to_active_element().find_element_by_tag_name('span')
+        self.assertEqual(element, focused_element)
+
+    def test_gui_tutorials(self):
+
+        self.login(username='emptyuser')
+
+        self.driver.find_element_by_css_selector('#wirecloud_header .user_menu_wrapper .styled_button > div, #wirecloud_header .arrow-down-settings').click()
+        self.popup_menu_click(('Tutorials', 'Basic concepts'))
+        next_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Next']")
+        self.assertElementHasFocus(next_button)
+        next_button.click()
+
+        WebDriverWait(self.driver, 5, ignored_exceptions=(StaleElementReferenceException,)).until(lambda driver: self.get_current_workspace_name() == 'Basic concepts tutorial')
+        next_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Next']")
+        self.assertElementHasFocus(next_button)
+        next_button.click()
+
+        WebDriverWait(self.driver, 10).until(element_to_be_clickable((By.CSS_SELECTOR, '#wirecloud_header .menu .marketplace')))
+        self.change_main_view('marketplace')
+        next_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Next']")
+        self.assertElementHasFocus(next_button)
+        next_button.click()
+
+        next_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Next']")
+        self.assertElementHasFocus(next_button)
+        next_button.click()
+
+        time.sleep(5)
+
+        testcase = self
+        def youtube_instantiable(driver):
+            resource = testcase.search_in_catalogue_results('YouTube Browser')
+            return element_to_be_clickable((By.CSS_SELECTOR, '.instantiate_button div'), base_element=resource)(driver)
+        WebDriverWait(self.driver, 10).until(youtube_instantiable).click()
+        next_button = self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Next']")
+        self.assertElementHasFocus(next_button)
+        next_button.click()
+
+        WebDriverWait(self.driver, 10).until(element_to_be_clickable((By.CSS_SELECTOR, '#wirecloud_header .menu .marketplace')))
+        self.change_main_view('marketplace')
+
+        time.sleep(5)
+
+        testcase = self
+        def input_box_instantiable(driver):
+            resource = testcase.search_in_catalogue_results('Input Box')
+            return element_to_be_clickable((By.CSS_SELECTOR, '.instantiate_button div'), base_element=resource)(driver)
+        WebDriverWait(self.driver, 10).until(input_box_instantiable).click()
+        self.wait_element_visible_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Cancel']").click()
+
+        window_menues = self.driver.find_elements_by_css_selector('.window_menu')
+        self.assertEqual(len(window_menues), 1)
+    test_gui_tutorials.tags = ('fiware-ut-15',)
+
+
+@wirecloud_selenium_test_case
+class BasicMobileSeleniumTests(MobileWirecloudSeleniumTestCase):
+
+    fixtures = ('initial_data', 'selenium_test_data', 'user_with_workspaces')
+    tags = ('mobile',)
+
+    def check_basic_workspace(self, frame_id=None):
+
+        iwidget_icons = self.driver.find_elements_by_css_selector('.iwidget_item')
+
+        # Send event from Test 2 as it is the one connected to the test operator
+        iwidget_icons[1].click()
+        source_iwidget = self.get_current_iwidgets()[1]
+
+        with source_iwidget:
+            self.assertEqual(self.driver.find_element_by_id('listPref').text, 'default')
+            self.assertEqual(self.driver.find_element_by_id('textPref').text, 'initial text')
+            self.assertEqual(self.driver.find_element_by_id('booleanPref').text, 'false')
+            self.assertEqual(self.driver.find_element_by_id('passwordPref').text, 'default')
+
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+            #self.driver.find_element_by_id('b1').click()
+
+        self.driver.find_element_by_css_selector('.dragboard .toolbar .back_button > .menu_text').click()
+        time.sleep(0.2)
+
+        iwidget_icons[0].click()
+        target_iwidget = self.get_current_iwidgets()[0]
+
+        with target_iwidget:
+
+            try:
+                WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text != '')
+            except:
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'hello world!!')
+
+    def test_basic_widget_functionalities(self):
+
+        self.login(username='user_with_workspaces')
+        self.wait_element_visible_by_css_selector('.iwidget_item')
+
+        self.check_basic_workspace()
+
+    def test_public_workspaces(self):
+
+        self.login(username='emptyuser', next='/user_with_workspaces/Public Workspace')
+        self.wait_element_visible_by_css_selector('.iwidget_item')
+
+        self.check_basic_workspace()
