@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,13 +17,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
-try:
-    from django.conf.urls import patterns, include, url
-except ImportError:  # pragma: no cover
-    # for Django version less than 1.4
-    from django.conf.urls.defaults import patterns, include, url
+from django.conf.urls import patterns, include, url
 from django.views.decorators.cache import cache_page
+from django.views.generic import TemplateView
 from django.views.i18n import javascript_catalog
 
 from wirecloud.platform import views
@@ -53,15 +49,16 @@ urlpatterns = patterns('wirecloud.platform.views',
         cache_page(60 * 60 * 24)(javascript_catalog), {'packages': ()},
         name="wirecloud.javascript_translation_catalogue"),
 
-    url(r'^api/workspace/(?P<workspace_id>\d+)/wiring$',
-        wiring_views.WiringEntry(permitted_methods=('PUT',)),
-        name='wirecloud.workspace_wiring'),
-
     # Context
     url(r'^api/context/?$',
         context_views.PlatformContextCollection(permitted_methods=('GET',)),
         name='wirecloud.platform_context_collection'),
 
+    url(r'^showcase/media/(?P<vendor>[^/]+)/(?P<name>[^/]+)/(?P<version>[^/]+)/(?P<file_path>.+)$',
+        widget_views.serve_showcase_media,
+        name='wirecloud.showcase_media'
+    ),
+
     # Widgets
     url(r'^api/resources/?$',
         localcatalogue_views.ResourceCollection(permitted_methods=('GET', 'POST',)),
@@ -146,9 +143,13 @@ urlpatterns = patterns('wirecloud.platform.views',
         name='wirecloud.workspace_entry'
     ),
     url(r'^api/workspace/(?P<workspace_id>\d+)/tabs/?$',
-        workspace_views.TabCollection(permitted_methods=('POST', 'PUT',)),
+        workspace_views.TabCollection(permitted_methods=('POST',)),
         name='wirecloud.tab_collection'
     ),
+    url(r'^api/workspace/(?P<workspace_id>\d+)/tabs/order/?$',
+        workspace_views.TabOrderService(),
+        name='wirecloud.tab_order'
+    ),
     url(r'^api/workspace/(?P<workspace_id>\d+)/tab/(?P<tab_id>\w+)/?$',
         workspace_views.TabEntry(permitted_methods=('PUT', 'DELETE',)),
         name='wirecloud.tab_entry'
@@ -159,9 +160,14 @@ urlpatterns = patterns('wirecloud.platform.views',
         name='wirecloud.variable_collection'
     ),
 
-    url(r'^api/workspace/(?P<workspace_id>\d+)/share/(?P<share_boolean>\w+)/?$',
-        workspace_views.WorkspaceSharerEntry(permitted_methods=('PUT',)),
-        name='wirecloud.workspace_share'
+    url(r'^api/workspace/(?P<workspace_id>\d+)/resources$',
+        localcatalogue_views.WorkspaceResourceCollection(permitted_methods=('GET',)),
+        name='wirecloud.workspace_resource_collection'
+    ),
+
+    url(r'^api/workspace/(?P<workspace_id>\d+)/wiring$',
+        wiring_views.WiringEntry(permitted_methods=('PUT',)),
+        name='wirecloud.workspace_wiring'
     ),
 
     url(r'^api/workspace/(?P<to_ws_id>\d+)/merge/?$',
@@ -174,7 +180,11 @@ urlpatterns = patterns('wirecloud.platform.views',
         name='wirecloud.workspace_publish'
     ),
 
+    url('^oauth2/default_redirect_uri$',
+        TemplateView.as_view(template_name='wirecloud/oauth2/default_redirect_uri.html'),
+        name='oauth.default_redirect_uri'),
+
 ) + get_plugin_urls() + patterns('wirecloud.platform.views',
 
-    url(r'^(?P<creator_user>[^/]+)/(?P<workspace>[^/]+)/?$', 'render_workspace_view', name='wirecloud.workspace_view'),
+    url(r'^(?P<owner>[^/]+)/(?P<name>[^/]+)/?$', 'render_workspace_view', name='wirecloud.workspace_view'),
 )
