@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 import codecs
@@ -370,7 +370,7 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
 
     def test_basic_wiring_editor_operations(self):
 
-        if not selenium_supports_draganddrop(self.driver):
+        if not selenium_supports_draganddrop(self.driver):  # pragma: no cover
             raise unittest.SkipTest('This test need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
         self.login()
@@ -407,7 +407,7 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         with iwidgets[1]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -420,7 +420,102 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             text_div = self.driver.find_element_by_id('wiringOut')
             self.assertEqual(text_div.text, '')
-    test_basic_wiring_editor_operations.tags = ('wiring', 'fiware-ut-6')
+    test_basic_wiring_editor_operations.tags = ('wiring', 'wiring_editor', 'fiware-ut-6')
+
+    def test_wiring_editor_modify_arrow_endpoints(self):
+
+        if not selenium_supports_draganddrop(self.driver):  # pragma: no cover
+            raise unittest.SkipTest('This test need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
+
+        self.login()
+
+        self.add_widget_to_mashup('Test', new_name='Test (1)')
+        self.add_widget_to_mashup('Test', new_name='Test (2)')
+        self.add_widget_to_mashup('Test', new_name='Test (3)')
+        iwidgets = self.get_current_iwidgets()
+
+        self.change_main_view('wiring')
+        grid = self.driver.find_element_by_xpath("//*[contains(@class, 'container center_container grid')]")
+
+        source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (1)']")
+        ActionChains(self.driver).click_and_hold(source).move_to_element(grid).move_by_offset(-80, -80).release().perform()
+
+        source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (2)']")
+        ActionChains(self.driver).click_and_hold(source).move_to_element(grid).move_by_offset(40, 40).release().perform()
+
+        source = self.driver.find_element_by_xpath("//*[contains(@class, 'container iwidget')]//*[text()='Test (3)']")
+        ActionChains(self.driver).click_and_hold(source).move_to_element(grid).move_by_offset(80, 70).release().perform()
+
+        source = iwidgets[0].get_wiring_endpoint('outputendpoint')
+        target = iwidgets[1].get_wiring_endpoint('inputendpoint')
+        ActionChains(self.driver).drag_and_drop(source.element, target.element).perform()
+
+        self.change_main_view('workspace')
+
+        with iwidgets[0]:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+
+        time.sleep(0.2)
+
+        with iwidgets[1]:
+            try:
+                WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'hello world!!')
+            except:  # pragma: no cover
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'hello world!!')
+
+        with iwidgets[2]:
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, '')
+
+        with iwidgets[0]:
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, '')
+
+        self.change_main_view('wiring')
+
+        source = iwidgets[0].get_wiring_endpoint('outputendpoint')
+        target = iwidgets[1].get_wiring_endpoint('inputendpoint')
+        target2 = iwidgets[2].get_wiring_endpoint('inputendpoint')
+        arrows = grid.find_elements_by_css_selector('.arrow')
+        self.assertEqual(len(arrows), 1)
+        arrows[0].find_element_by_css_selector('g').click()
+
+        ActionChains(self.driver).drag_and_drop(target.element, target2.element).perform()
+
+        arrows = grid.find_elements_by_css_selector('.arrow')
+        self.assertEqual(len(arrows), 1)
+
+        self.change_main_view('workspace')
+
+        with iwidgets[0]:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello new world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+
+        with iwidgets[2]:
+
+            try:
+                WebDriverWait(self.driver, timeout=2).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'hello new world!!')
+            except:  # pragma: no cover
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'hello new world!!')
+
+        with iwidgets[1]:
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'hello world!!')
+
+        with iwidgets[0]:
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, '')
 
     def test_widget_preferences_in_wiring_editor(self):
 
@@ -466,7 +561,7 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
 
         self.change_main_view('wiring')
 
-        # Change widget settings
+        # Change operator settings
         ioperator = self.get_current_wiring_editor_ioperators()[0]
         ioperator.element.find_element_by_css_selector('.specialIcon').click()
         self.wait_element_visible_by_css_selector('.editPos_button', element=ioperator.element).click()
@@ -482,7 +577,7 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             try:
                 WebDriverWait(self.driver, timeout=10).until(lambda driver: driver.find_element_by_id('wiringOut').text != '')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -500,12 +595,103 @@ class WiringSeleniumTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             try:
                 WebDriverWait(self.driver, timeout=10).until(lambda driver: driver.find_element_by_id('wiringOut').text != 'preferences changed: prefix')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
             self.assertEqual(text_div.text, 'prefix: hello world!!')
 
+    def test_input_endpoint_exceptions(self):
+
+        self.login(username='user_with_workspaces')
+
+        iwidgets = self.get_current_iwidgets()
+        source_iwidget = iwidgets[0]
+        target_iwidget = iwidgets[1]
+        self.assertIsNotNone(source_iwidget.element)
+        self.assertIsNotNone(target_iwidget.element)
+
+        target_iwidget.perform_action('Settings')
+
+        boolean_input = self.driver.find_element_by_css_selector('.window_menu [name="boolean"]')
+        boolean_input.click()
+
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
+        self.assertEqual(source_iwidget.error_count, 0)
+        self.assertEqual(target_iwidget.error_count, 0)
+        with source_iwidget:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+            #self.driver.find_element_by_id('b1').click()
+
+        WebDriverWait(self.driver, timeout=10).until(lambda driver: target_iwidget.error_count == 1)
+        self.assertEqual(source_iwidget.error_count, 0)
+
+        with target_iwidget:
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, '')
+
+        # Test exception on the operator input endpoint
+        source_iwidget = iwidgets[1]
+        target_iwidget = iwidgets[0]
+
+        self.change_main_view('wiring')
+
+        # Change operator settings
+        ioperator = self.get_current_wiring_editor_ioperators()[0]
+        ioperator.element.find_element_by_css_selector('.specialIcon').click()
+        self.wait_element_visible_by_css_selector('.editPos_button', element=ioperator.element).click()
+        self.popup_menu_click('Settings')
+
+        self.driver.find_element_by_css_selector('.window_menu [name="exception_on_event"]').click()
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
+        self.change_main_view('workspace')
+
+        with source_iwidget:
+            text_input = self.driver.find_element_by_tag_name('input')
+            self.fill_form_input(text_input, 'hello world!!')
+            # Work around hang when using Firefox Driver
+            self.driver.execute_script('sendEvent();')
+            #self.driver.find_element_by_id('b1').click()
+
+        self.change_main_view('wiring')
+        ioperator = self.get_current_wiring_editor_ioperators()[0]
+        self.assertEqual(ioperator.error_count, 1)
+        self.assertEqual(target_iwidget.error_count, 0)
+
+    def test_operator_logging_support(self):
+
+        self.login(username='user_with_workspaces')
+
+        self.change_main_view('wiring')
+
+        ioperator = self.get_current_wiring_editor_ioperators()[0]
+        self.assertEqual(ioperator.error_count, 0)
+
+        # Change operator settings
+        ioperator.element.find_element_by_css_selector('.specialIcon').click()
+        self.wait_element_visible_by_css_selector('.editPos_button', element=ioperator.element).click()
+        self.popup_menu_click('Settings')
+
+        self.driver.find_element_by_css_selector('.window_menu [name="test_logging"]').click()
+        self.driver.find_element_by_xpath("//*[contains(@class, 'window_menu')]//*[text()='Accept']").click()
+
+        self.assertEqual(ioperator.error_count, 2)
+        self.assertEqual(len(ioperator.log_entries), 5)
+
+        with self.get_current_iwidgets()[0]:
+            try:
+                WebDriverWait(self.driver, timeout=10).until(lambda driver: driver.find_element_by_id('wiringOut').text != '')
+            except:
+                pass
+
+            text_div = self.driver.find_element_by_id('wiringOut')
+            self.assertEqual(text_div.text, 'preferences changed: test_logging')
+
 
 class WiringRecoveringTestCase(WirecloudSeleniumTestCase):
 
@@ -601,7 +787,7 @@ class WiringRecoveringTestCase(WirecloudSeleniumTestCase):
         with iwidgets[1]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -1301,7 +1487,7 @@ class EndpointOrderTestCase(WirecloudSeleniumTestCase):
 
         super(EndpointOrderTestCase, cls).setUpClass()
 
-        if not selenium_supports_draganddrop(cls.driver):
+        if not selenium_supports_draganddrop(cls.driver):  # pragma: no cover
             cls.tearDownClass()
             raise unittest.SkipTest('Endpoint reordering tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
@@ -1403,7 +1589,7 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
 
         super(MulticonnectorTestCase, cls).setUpClass()
 
-        if not selenium_supports_draganddrop(cls.driver):
+        if not selenium_supports_draganddrop(cls.driver):  # pragma: no cover
             cls.tearDownClass()
             raise unittest.SkipTest('Multiconnector tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
@@ -1488,7 +1674,7 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         with iwidgets[1]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'first hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -1497,7 +1683,7 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         with iwidgets[2]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'first hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -1547,7 +1733,7 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'first hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -1565,7 +1751,7 @@ class MulticonnectorTestCase(WirecloudSeleniumTestCase):
         with iwidgets[0]:
             try:
                 WebDriverWait(self.driver, timeout=30).until(lambda driver: driver.find_element_by_id('wiringOut').text == 'second hello world!!')
-            except:
+            except:  # pragma: no cover
                 pass
 
             text_div = self.driver.find_element_by_id('wiringOut')
@@ -1582,11 +1768,11 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
 
         super(StickyEffectTestCase, cls).setUpClass()
 
-        if not selenium_supports_draganddrop(cls.driver):
+        if not selenium_supports_draganddrop(cls.driver):  # pragma: no cover
             cls.tearDownClass()
             raise unittest.SkipTest('Sticky effect tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
-    def test_wiring_stycky_effect_in_endpoint_label(self):
+    def test_wiring_sticky_effect_in_endpoint_label(self):
         self.login()
 
         self.add_widget_to_mashup('Test', new_name='Test (1)')
@@ -1603,7 +1789,6 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
 
         operator = self.driver.find_element_by_xpath("//*[contains(@class, 'container ioperator')]//*[text()='TestOperator']")
         ActionChains(self.driver).click_and_hold(operator).move_to_element(grid).move_by_offset(-220, -120).release().perform()
-
         ioperator = self.get_current_wiring_editor_ioperators()[0]
 
         widgetInput = iwidgets[0].get_wiring_endpoint('inputendpoint')
@@ -1611,7 +1796,7 @@ class StickyEffectTestCase(WirecloudSeleniumTestCase):
         operatorInput = ioperator.get_wiring_endpoint('input')
         operatorOutput = ioperator.get_wiring_endpoint('output')
 
-        # Try to connect using stycky effect in label endpoints
+        # Try to connect using sticky effect in label endpoints
         ActionChains(self.driver).drag_and_drop(widgetOutput.element, operatorInput.label).perform()
         ActionChains(self.driver).drag_and_drop(operatorOutput.element, widgetInput.label).perform()
 
@@ -1638,7 +1823,7 @@ class SimpleRecommendationsTestCase(WirecloudSeleniumTestCase):
 
         super(SimpleRecommendationsTestCase, cls).setUpClass()
 
-        if not selenium_supports_draganddrop(cls.driver):
+        if not selenium_supports_draganddrop(cls.driver):  # pragma: no cover
             cls.tearDownClass()
             raise unittest.SkipTest('Simple recommendation tests need make use of the native events support on selenium <= 2.37.2 when using FirefoxDriver (not available on Mac OS)')
 
