@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 from django.template import loader, Context
@@ -43,12 +43,16 @@ def remove_related_iwidget_connections(wiring, iwidget):
             del wiring['views'][0]['connections'][connection['index']]
 
 
-def generate_xhtml_operator_code(js_files, base_url, request):
+def get_operator_cache_key(operator, domain, mode):
+    return '_operator_xhtml/%s/%s/%s?mode=%s' % (operator.cache_version, domain, operator.id, mode)
+
+
+def generate_xhtml_operator_code(js_files, base_url, request, requirements, mode):
 
     api_url = get_absolute_static_url('js/WirecloudAPI/WirecloudOperatorAPI.js', request=request)
     api_common_url = get_absolute_static_url('js/WirecloudAPI/WirecloudAPICommon.js', request=request)
     api_closure_url = get_absolute_static_url('js/WirecloudAPI/WirecloudAPIClosure.js', request=request)
-    api_js_files = [get_absolute_static_url(url, request=request) for url in get_operator_api_extensions('index')]
+    api_js_files = [get_absolute_static_url(url, request=request) for url in get_operator_api_extensions(mode, requirements)]
     api_js = [api_url, api_common_url] + api_js_files + [api_closure_url]
 
     t = loader.get_template('wirecloud/operator_xhtml.html')
