@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -25,24 +25,22 @@ except ImportError:
 import json
 
 from django.conf import settings
+from django.db.models import Q
 from django.shortcuts import get_object_or_404
 from django.utils.translation import ugettext as _
 
 from wirecloud.commons.utils.db import save_alternative
 from wirecloud.commons.utils.template import TemplateParser
-from wirecloud.platform.iwidget.utils import deleteIWidget
-from wirecloud.platform.models import IWidget, PublishedWorkspace, Tab, UserWorkspace, VariableValue, Workspace
+from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Variable, Workspace
 from wirecloud.platform.workspace.managers import get_workspace_managers
-from wirecloud.platform.workspace.packageLinker import PackageLinker
 
 
 def deleteTab(tab, user):
-    #Deleting iwidgets
-    iwidgets = IWidget.objects.filter(tab=tab)
-    for iwidget in iwidgets:
-        deleteIWidget(iwidget, user)
+    # Delete iwidgets
+    for iwidget in tab.iwidget_set.all():
+        iwidget.delete()
 
-    # Deleting tab
+    # Delete tab
     tab.delete()
 
 
@@ -97,18 +95,17 @@ def decrypt_value(value):
         return ''
 
 
-def set_variable_value(var_id, user, value):
+def set_variable_value(var_id, value):
 
-    variable_value = VariableValue.objects.select_related('variable__vardef').get(user=user, variable__id=var_id)
-    variable_value.set_variable_value(value)
-    variable_value.save()
+    variable = Variable.objects.select_related('vardef').get(id=var_id)
+    variable.set_variable_value(value)
+    variable.save()
 
 
 def sync_base_workspaces(user):
 
     from wirecloud.platform.workspace.mashupTemplateParser import buildWorkspaceFromTemplate
 
-    packageLinker = PackageLinker()
     reload_showcase = False
     managers = get_workspace_managers()
 
@@ -139,10 +136,9 @@ def sync_base_workspaces(user):
         for workspace_to_add in result[1]:
             from_workspace = workspace_to_add[1]
 
-            if isinstance(from_workspace, Workspace):
-                user_workspace = packageLinker.link_workspace(from_workspace, user, from_workspace.creator)
-            elif isinstance(from_workspace, PublishedWorkspace):
-                _junk, user_workspace = buildWorkspaceFromTemplate(from_workspace.template, user)
+            if isinstance(from_workspace, CatalogueResource):
+                # TODO
+                continue
             else:
                 # TODO warning
                 continue
@@ -157,24 +153,27 @@ def sync_base_workspaces(user):
 
 def get_workspace_list(user):
 
-    from wirecloud.platform.workspace.views import createEmptyWorkspace, setActiveWorkspace
+    from wirecloud.platform.workspace.views import setActiveWorkspace
 
-    reload_showcase = sync_base_workspaces(user)
+    if not user.is_authenticated():
+        workspaces = Workspace.objects.filter(public=True)
+        return workspaces, None
 
-    if Workspace.objects.filter(users=user).count() == 0:
-        # create an empty workspace
-        createEmptyWorkspace(_('Workspace'), user)
+    sync_base_workspaces(user)
 
-    # Now we can fetch all the workspaces of an user
-    workspaces = Workspace.objects.filter(users__id=user.id)
+    # Now we can fetch all the workspaces for the user
+    workspaces = Workspace.objects.filter(Q(public=True) | Q(users__id=user.id))
 
     # if there is no active workspace
     active_workspaces = UserWorkspace.objects.filter(user=user, active=True)
     if len(active_workspaces) == 0:
 
-        # set the first workspace as active
-        active_workspace = UserWorkspace.objects.filter(user=user)[0]
-        setActiveWorkspace(user, active_workspace.workspace)
+        try:
+            # set the first workspace as active
+            active_workspace = UserWorkspace.objects.filter(user=user)[0]
+            setActiveWorkspace(user, active_workspace.workspace)
+        except IndexError:
+            active_workspace = None
 
     elif len(active_workspaces) > 1:
 
@@ -184,4 +183,4 @@ def get_workspace_list(user):
     else:
         active_workspace = active_workspaces[0]
 
-    return workspaces, active_workspace, reload_showcase
+    return workspaces, active_workspace
